from enum import Enum
import math
import string


class PressureUnits(Enum):
        """
            PressureUnits enumeration
        """
        
        Pascal = 'pascal'
        """
            
        """
        
        Atmosphere = 'atmosphere'
        """
            
        """
        
        Bar = 'bar'
        """
            
        """
        
        KilogramForcePerSquareMeter = 'kilogram_force_per_square_meter'
        """
            
        """
        
        KilogramForcePerSquareCentimeter = 'kilogram_force_per_square_centimeter'
        """
            
        """
        
        KilogramForcePerSquareMillimeter = 'kilogram_force_per_square_millimeter'
        """
            
        """
        
        NewtonPerSquareMeter = 'newton_per_square_meter'
        """
            
        """
        
        NewtonPerSquareCentimeter = 'newton_per_square_centimeter'
        """
            
        """
        
        NewtonPerSquareMillimeter = 'newton_per_square_millimeter'
        """
            
        """
        
        TechnicalAtmosphere = 'technical_atmosphere'
        """
            
        """
        
        Torr = 'torr'
        """
            
        """
        
        PoundForcePerSquareInch = 'pound_force_per_square_inch'
        """
            
        """
        
        PoundForcePerSquareMil = 'pound_force_per_square_mil'
        """
            
        """
        
        PoundForcePerSquareFoot = 'pound_force_per_square_foot'
        """
            
        """
        
        TonneForcePerSquareMillimeter = 'tonne_force_per_square_millimeter'
        """
            
        """
        
        TonneForcePerSquareMeter = 'tonne_force_per_square_meter'
        """
            
        """
        
        MeterOfHead = 'meter_of_head'
        """
            
        """
        
        TonneForcePerSquareCentimeter = 'tonne_force_per_square_centimeter'
        """
            
        """
        
        FootOfHead = 'foot_of_head'
        """
            
        """
        
        MillimeterOfMercury = 'millimeter_of_mercury'
        """
            
        """
        
        InchOfMercury = 'inch_of_mercury'
        """
            
        """
        
        DynePerSquareCentimeter = 'dyne_per_square_centimeter'
        """
            
        """
        
        PoundPerInchSecondSquared = 'pound_per_inch_second_squared'
        """
            
        """
        
        MeterOfWaterColumn = 'meter_of_water_column'
        """
            
        """
        
        InchOfWaterColumn = 'inch_of_water_column'
        """
            
        """
        
        MeterOfElevation = 'meter_of_elevation'
        """
            
        """
        
        FootOfElevation = 'foot_of_elevation'
        """
            
        """
        
        Micropascal = 'micropascal'
        """
            
        """
        
        Millipascal = 'millipascal'
        """
            
        """
        
        Decapascal = 'decapascal'
        """
            
        """
        
        Hectopascal = 'hectopascal'
        """
            
        """
        
        Kilopascal = 'kilopascal'
        """
            
        """
        
        Megapascal = 'megapascal'
        """
            
        """
        
        Gigapascal = 'gigapascal'
        """
            
        """
        
        Microbar = 'microbar'
        """
            
        """
        
        Millibar = 'millibar'
        """
            
        """
        
        Centibar = 'centibar'
        """
            
        """
        
        Decibar = 'decibar'
        """
            
        """
        
        Kilobar = 'kilobar'
        """
            
        """
        
        Megabar = 'megabar'
        """
            
        """
        
        KilonewtonPerSquareMeter = 'kilonewton_per_square_meter'
        """
            
        """
        
        MeganewtonPerSquareMeter = 'meganewton_per_square_meter'
        """
            
        """
        
        KilonewtonPerSquareCentimeter = 'kilonewton_per_square_centimeter'
        """
            
        """
        
        KilonewtonPerSquareMillimeter = 'kilonewton_per_square_millimeter'
        """
            
        """
        
        KilopoundForcePerSquareInch = 'kilopound_force_per_square_inch'
        """
            
        """
        
        KilopoundForcePerSquareMil = 'kilopound_force_per_square_mil'
        """
            
        """
        
        KilopoundForcePerSquareFoot = 'kilopound_force_per_square_foot'
        """
            
        """
        
        MillimeterOfWaterColumn = 'millimeter_of_water_column'
        """
            
        """
        
        CentimeterOfWaterColumn = 'centimeter_of_water_column'
        """
            
        """
        

class Pressure:
    """
    Pressure (symbol: P or p) is the ratio of force to the area over which that force is distributed. Pressure is force per unit area applied in a direction perpendicular to the surface of an object. Gauge pressure (also spelled gage pressure)[a] is the pressure relative to the local atmospheric or ambient pressure. Pressure is measured in any unit of force divided by any unit of area. The SI unit of pressure is the newton per square metre, which is called the pascal (Pa) after the seventeenth-century philosopher and scientist Blaise Pascal. A pressure of 1 Pa is small; it approximately equals the pressure exerted by a dollar bill resting flat on a table. Everyday pressures are often stated in kilopascals (1 kPa = 1000 Pa).

    Args:
        value (float): The value.
        from_unit (PressureUnits): The Pressure unit to create from, The default unit is Pascal
    """
    def __init__(self, value: float, from_unit: PressureUnits = PressureUnits.Pascal):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__pascals = None
        
        self.__atmospheres = None
        
        self.__bars = None
        
        self.__kilograms_force_per_square_meter = None
        
        self.__kilograms_force_per_square_centimeter = None
        
        self.__kilograms_force_per_square_millimeter = None
        
        self.__newtons_per_square_meter = None
        
        self.__newtons_per_square_centimeter = None
        
        self.__newtons_per_square_millimeter = None
        
        self.__technical_atmospheres = None
        
        self.__torrs = None
        
        self.__pounds_force_per_square_inch = None
        
        self.__pounds_force_per_square_mil = None
        
        self.__pounds_force_per_square_foot = None
        
        self.__tonnes_force_per_square_millimeter = None
        
        self.__tonnes_force_per_square_meter = None
        
        self.__meters_of_head = None
        
        self.__tonnes_force_per_square_centimeter = None
        
        self.__feet_of_head = None
        
        self.__millimeters_of_mercury = None
        
        self.__inches_of_mercury = None
        
        self.__dynes_per_square_centimeter = None
        
        self.__pounds_per_inch_second_squared = None
        
        self.__meters_of_water_column = None
        
        self.__inches_of_water_column = None
        
        self.__meters_of_elevation = None
        
        self.__feet_of_elevation = None
        
        self.__micropascals = None
        
        self.__millipascals = None
        
        self.__decapascals = None
        
        self.__hectopascals = None
        
        self.__kilopascals = None
        
        self.__megapascals = None
        
        self.__gigapascals = None
        
        self.__microbars = None
        
        self.__millibars = None
        
        self.__centibars = None
        
        self.__decibars = None
        
        self.__kilobars = None
        
        self.__megabars = None
        
        self.__kilonewtons_per_square_meter = None
        
        self.__meganewtons_per_square_meter = None
        
        self.__kilonewtons_per_square_centimeter = None
        
        self.__kilonewtons_per_square_millimeter = None
        
        self.__kilopounds_force_per_square_inch = None
        
        self.__kilopounds_force_per_square_mil = None
        
        self.__kilopounds_force_per_square_foot = None
        
        self.__millimeters_of_water_column = None
        
        self.__centimeters_of_water_column = None
        

    def __convert_from_base(self, from_unit: PressureUnits) -> float:
        value = self.__value
        
        if from_unit == PressureUnits.Pascal:
            return (value)
        
        if from_unit == PressureUnits.Atmosphere:
            return (value / (1.01325 * 1e5))
        
        if from_unit == PressureUnits.Bar:
            return (value / 1e5)
        
        if from_unit == PressureUnits.KilogramForcePerSquareMeter:
            return (value * 0.101971619222242)
        
        if from_unit == PressureUnits.KilogramForcePerSquareCentimeter:
            return (value / 9.80665e4)
        
        if from_unit == PressureUnits.KilogramForcePerSquareMillimeter:
            return (value / 9.80665e6)
        
        if from_unit == PressureUnits.NewtonPerSquareMeter:
            return (value)
        
        if from_unit == PressureUnits.NewtonPerSquareCentimeter:
            return (value / 1e4)
        
        if from_unit == PressureUnits.NewtonPerSquareMillimeter:
            return (value / 1e6)
        
        if from_unit == PressureUnits.TechnicalAtmosphere:
            return (value / (9.80680592331 * 1e4))
        
        if from_unit == PressureUnits.Torr:
            return (value / (1.3332266752 * 1e2))
        
        if from_unit == PressureUnits.PoundForcePerSquareInch:
            return (value / 6.894757293168361e3)
        
        if from_unit == PressureUnits.PoundForcePerSquareMil:
            return (value / 6.894757293168361e9)
        
        if from_unit == PressureUnits.PoundForcePerSquareFoot:
            return (value / 4.788025898033584e1)
        
        if from_unit == PressureUnits.TonneForcePerSquareMillimeter:
            return (value / 9.80665e9)
        
        if from_unit == PressureUnits.TonneForcePerSquareMeter:
            return (value / 9.80665e3)
        
        if from_unit == PressureUnits.MeterOfHead:
            return (value * 0.0001019977334)
        
        if from_unit == PressureUnits.TonneForcePerSquareCentimeter:
            return (value / 9.80665e7)
        
        if from_unit == PressureUnits.FootOfHead:
            return (value * 0.000334552565551)
        
        if from_unit == PressureUnits.MillimeterOfMercury:
            return (value * 7.50061561302643e-3)
        
        if from_unit == PressureUnits.InchOfMercury:
            return (value * 2.95299830714159e-4)
        
        if from_unit == PressureUnits.DynePerSquareCentimeter:
            return (value / 1.0e-1)
        
        if from_unit == PressureUnits.PoundPerInchSecondSquared:
            return (value / 1.785796732283465e1)
        
        if from_unit == PressureUnits.MeterOfWaterColumn:
            return (value / 9.806650000000272e3)
        
        if from_unit == PressureUnits.InchOfWaterColumn:
            return (value / 249.08890833333)
        
        if from_unit == PressureUnits.MeterOfElevation:
            return ((1.0 - math.pow(value / 101325.0, 0.190284)) * 44307.69396)
        
        if from_unit == PressureUnits.FootOfElevation:
            return ((1.0 - math.pow(value / 101325.0, 0.190284)) * 145366.45)
        
        if from_unit == PressureUnits.Micropascal:
            return ((value) / 1e-06)
        
        if from_unit == PressureUnits.Millipascal:
            return ((value) / 0.001)
        
        if from_unit == PressureUnits.Decapascal:
            return ((value) / 10.0)
        
        if from_unit == PressureUnits.Hectopascal:
            return ((value) / 100.0)
        
        if from_unit == PressureUnits.Kilopascal:
            return ((value) / 1000.0)
        
        if from_unit == PressureUnits.Megapascal:
            return ((value) / 1000000.0)
        
        if from_unit == PressureUnits.Gigapascal:
            return ((value) / 1000000000.0)
        
        if from_unit == PressureUnits.Microbar:
            return ((value / 1e5) / 1e-06)
        
        if from_unit == PressureUnits.Millibar:
            return ((value / 1e5) / 0.001)
        
        if from_unit == PressureUnits.Centibar:
            return ((value / 1e5) / 0.01)
        
        if from_unit == PressureUnits.Decibar:
            return ((value / 1e5) / 0.1)
        
        if from_unit == PressureUnits.Kilobar:
            return ((value / 1e5) / 1000.0)
        
        if from_unit == PressureUnits.Megabar:
            return ((value / 1e5) / 1000000.0)
        
        if from_unit == PressureUnits.KilonewtonPerSquareMeter:
            return ((value) / 1000.0)
        
        if from_unit == PressureUnits.MeganewtonPerSquareMeter:
            return ((value) / 1000000.0)
        
        if from_unit == PressureUnits.KilonewtonPerSquareCentimeter:
            return ((value / 1e4) / 1000.0)
        
        if from_unit == PressureUnits.KilonewtonPerSquareMillimeter:
            return ((value / 1e6) / 1000.0)
        
        if from_unit == PressureUnits.KilopoundForcePerSquareInch:
            return ((value / 6.894757293168361e3) / 1000.0)
        
        if from_unit == PressureUnits.KilopoundForcePerSquareMil:
            return ((value / 6.894757293168361e9) / 1000.0)
        
        if from_unit == PressureUnits.KilopoundForcePerSquareFoot:
            return ((value / 4.788025898033584e1) / 1000.0)
        
        if from_unit == PressureUnits.MillimeterOfWaterColumn:
            return ((value / 9.806650000000272e3) / 0.001)
        
        if from_unit == PressureUnits.CentimeterOfWaterColumn:
            return ((value / 9.806650000000272e3) / 0.01)
        
        return None


    def __convert_to_base(self, value: float, to_unit: PressureUnits) -> float:
        
        if to_unit == PressureUnits.Pascal:
            return (value)
        
        if to_unit == PressureUnits.Atmosphere:
            return (value * 1.01325 * 1e5)
        
        if to_unit == PressureUnits.Bar:
            return (value * 1e5)
        
        if to_unit == PressureUnits.KilogramForcePerSquareMeter:
            return (value * 9.80665019960652)
        
        if to_unit == PressureUnits.KilogramForcePerSquareCentimeter:
            return (value * 9.80665e4)
        
        if to_unit == PressureUnits.KilogramForcePerSquareMillimeter:
            return (value * 9.80665e6)
        
        if to_unit == PressureUnits.NewtonPerSquareMeter:
            return (value)
        
        if to_unit == PressureUnits.NewtonPerSquareCentimeter:
            return (value * 1e4)
        
        if to_unit == PressureUnits.NewtonPerSquareMillimeter:
            return (value * 1e6)
        
        if to_unit == PressureUnits.TechnicalAtmosphere:
            return (value * 9.80680592331 * 1e4)
        
        if to_unit == PressureUnits.Torr:
            return (value * 1.3332266752 * 1e2)
        
        if to_unit == PressureUnits.PoundForcePerSquareInch:
            return (value * 6.894757293168361e3)
        
        if to_unit == PressureUnits.PoundForcePerSquareMil:
            return (value * 6.894757293168361e9)
        
        if to_unit == PressureUnits.PoundForcePerSquareFoot:
            return (value * 4.788025898033584e1)
        
        if to_unit == PressureUnits.TonneForcePerSquareMillimeter:
            return (value * 9.80665e9)
        
        if to_unit == PressureUnits.TonneForcePerSquareMeter:
            return (value * 9.80665e3)
        
        if to_unit == PressureUnits.MeterOfHead:
            return (value * 9804.139432)
        
        if to_unit == PressureUnits.TonneForcePerSquareCentimeter:
            return (value * 9.80665e7)
        
        if to_unit == PressureUnits.FootOfHead:
            return (value * 2989.0669)
        
        if to_unit == PressureUnits.MillimeterOfMercury:
            return (value / 7.50061561302643e-3)
        
        if to_unit == PressureUnits.InchOfMercury:
            return (value / 2.95299830714159e-4)
        
        if to_unit == PressureUnits.DynePerSquareCentimeter:
            return (value * 1.0e-1)
        
        if to_unit == PressureUnits.PoundPerInchSecondSquared:
            return (value * 1.785796732283465e1)
        
        if to_unit == PressureUnits.MeterOfWaterColumn:
            return (value * 9.806650000000272e3)
        
        if to_unit == PressureUnits.InchOfWaterColumn:
            return (value * 249.08890833333)
        
        if to_unit == PressureUnits.MeterOfElevation:
            return (math.pow(1.0 - (value / 44307.69396), 5.2553026003237266401799415610351) * 101325.0)
        
        if to_unit == PressureUnits.FootOfElevation:
            return (math.pow(1.0 - (value / 145366.45), 5.2553026003237266401799415610351) * 101325.0)
        
        if to_unit == PressureUnits.Micropascal:
            return ((value) * 1e-06)
        
        if to_unit == PressureUnits.Millipascal:
            return ((value) * 0.001)
        
        if to_unit == PressureUnits.Decapascal:
            return ((value) * 10.0)
        
        if to_unit == PressureUnits.Hectopascal:
            return ((value) * 100.0)
        
        if to_unit == PressureUnits.Kilopascal:
            return ((value) * 1000.0)
        
        if to_unit == PressureUnits.Megapascal:
            return ((value) * 1000000.0)
        
        if to_unit == PressureUnits.Gigapascal:
            return ((value) * 1000000000.0)
        
        if to_unit == PressureUnits.Microbar:
            return ((value * 1e5) * 1e-06)
        
        if to_unit == PressureUnits.Millibar:
            return ((value * 1e5) * 0.001)
        
        if to_unit == PressureUnits.Centibar:
            return ((value * 1e5) * 0.01)
        
        if to_unit == PressureUnits.Decibar:
            return ((value * 1e5) * 0.1)
        
        if to_unit == PressureUnits.Kilobar:
            return ((value * 1e5) * 1000.0)
        
        if to_unit == PressureUnits.Megabar:
            return ((value * 1e5) * 1000000.0)
        
        if to_unit == PressureUnits.KilonewtonPerSquareMeter:
            return ((value) * 1000.0)
        
        if to_unit == PressureUnits.MeganewtonPerSquareMeter:
            return ((value) * 1000000.0)
        
        if to_unit == PressureUnits.KilonewtonPerSquareCentimeter:
            return ((value * 1e4) * 1000.0)
        
        if to_unit == PressureUnits.KilonewtonPerSquareMillimeter:
            return ((value * 1e6) * 1000.0)
        
        if to_unit == PressureUnits.KilopoundForcePerSquareInch:
            return ((value * 6.894757293168361e3) * 1000.0)
        
        if to_unit == PressureUnits.KilopoundForcePerSquareMil:
            return ((value * 6.894757293168361e9) * 1000.0)
        
        if to_unit == PressureUnits.KilopoundForcePerSquareFoot:
            return ((value * 4.788025898033584e1) * 1000.0)
        
        if to_unit == PressureUnits.MillimeterOfWaterColumn:
            return ((value * 9.806650000000272e3) * 0.001)
        
        if to_unit == PressureUnits.CentimeterOfWaterColumn:
            return ((value * 9.806650000000272e3) * 0.01)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_pascals(pascals: float):
        """
        Create a new instance of Pressure from a value in pascals.

        

        :param meters: The Pressure value in pascals.
        :type pascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(pascals, PressureUnits.Pascal)

    
    @staticmethod
    def from_atmospheres(atmospheres: float):
        """
        Create a new instance of Pressure from a value in atmospheres.

        

        :param meters: The Pressure value in atmospheres.
        :type atmospheres: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(atmospheres, PressureUnits.Atmosphere)

    
    @staticmethod
    def from_bars(bars: float):
        """
        Create a new instance of Pressure from a value in bars.

        

        :param meters: The Pressure value in bars.
        :type bars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(bars, PressureUnits.Bar)

    
    @staticmethod
    def from_kilograms_force_per_square_meter(kilograms_force_per_square_meter: float):
        """
        Create a new instance of Pressure from a value in kilograms_force_per_square_meter.

        

        :param meters: The Pressure value in kilograms_force_per_square_meter.
        :type kilograms_force_per_square_meter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilograms_force_per_square_meter, PressureUnits.KilogramForcePerSquareMeter)

    
    @staticmethod
    def from_kilograms_force_per_square_centimeter(kilograms_force_per_square_centimeter: float):
        """
        Create a new instance of Pressure from a value in kilograms_force_per_square_centimeter.

        

        :param meters: The Pressure value in kilograms_force_per_square_centimeter.
        :type kilograms_force_per_square_centimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilograms_force_per_square_centimeter, PressureUnits.KilogramForcePerSquareCentimeter)

    
    @staticmethod
    def from_kilograms_force_per_square_millimeter(kilograms_force_per_square_millimeter: float):
        """
        Create a new instance of Pressure from a value in kilograms_force_per_square_millimeter.

        

        :param meters: The Pressure value in kilograms_force_per_square_millimeter.
        :type kilograms_force_per_square_millimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilograms_force_per_square_millimeter, PressureUnits.KilogramForcePerSquareMillimeter)

    
    @staticmethod
    def from_newtons_per_square_meter(newtons_per_square_meter: float):
        """
        Create a new instance of Pressure from a value in newtons_per_square_meter.

        

        :param meters: The Pressure value in newtons_per_square_meter.
        :type newtons_per_square_meter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(newtons_per_square_meter, PressureUnits.NewtonPerSquareMeter)

    
    @staticmethod
    def from_newtons_per_square_centimeter(newtons_per_square_centimeter: float):
        """
        Create a new instance of Pressure from a value in newtons_per_square_centimeter.

        

        :param meters: The Pressure value in newtons_per_square_centimeter.
        :type newtons_per_square_centimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(newtons_per_square_centimeter, PressureUnits.NewtonPerSquareCentimeter)

    
    @staticmethod
    def from_newtons_per_square_millimeter(newtons_per_square_millimeter: float):
        """
        Create a new instance of Pressure from a value in newtons_per_square_millimeter.

        

        :param meters: The Pressure value in newtons_per_square_millimeter.
        :type newtons_per_square_millimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(newtons_per_square_millimeter, PressureUnits.NewtonPerSquareMillimeter)

    
    @staticmethod
    def from_technical_atmospheres(technical_atmospheres: float):
        """
        Create a new instance of Pressure from a value in technical_atmospheres.

        

        :param meters: The Pressure value in technical_atmospheres.
        :type technical_atmospheres: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(technical_atmospheres, PressureUnits.TechnicalAtmosphere)

    
    @staticmethod
    def from_torrs(torrs: float):
        """
        Create a new instance of Pressure from a value in torrs.

        

        :param meters: The Pressure value in torrs.
        :type torrs: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(torrs, PressureUnits.Torr)

    
    @staticmethod
    def from_pounds_force_per_square_inch(pounds_force_per_square_inch: float):
        """
        Create a new instance of Pressure from a value in pounds_force_per_square_inch.

        

        :param meters: The Pressure value in pounds_force_per_square_inch.
        :type pounds_force_per_square_inch: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(pounds_force_per_square_inch, PressureUnits.PoundForcePerSquareInch)

    
    @staticmethod
    def from_pounds_force_per_square_mil(pounds_force_per_square_mil: float):
        """
        Create a new instance of Pressure from a value in pounds_force_per_square_mil.

        

        :param meters: The Pressure value in pounds_force_per_square_mil.
        :type pounds_force_per_square_mil: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(pounds_force_per_square_mil, PressureUnits.PoundForcePerSquareMil)

    
    @staticmethod
    def from_pounds_force_per_square_foot(pounds_force_per_square_foot: float):
        """
        Create a new instance of Pressure from a value in pounds_force_per_square_foot.

        

        :param meters: The Pressure value in pounds_force_per_square_foot.
        :type pounds_force_per_square_foot: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(pounds_force_per_square_foot, PressureUnits.PoundForcePerSquareFoot)

    
    @staticmethod
    def from_tonnes_force_per_square_millimeter(tonnes_force_per_square_millimeter: float):
        """
        Create a new instance of Pressure from a value in tonnes_force_per_square_millimeter.

        

        :param meters: The Pressure value in tonnes_force_per_square_millimeter.
        :type tonnes_force_per_square_millimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(tonnes_force_per_square_millimeter, PressureUnits.TonneForcePerSquareMillimeter)

    
    @staticmethod
    def from_tonnes_force_per_square_meter(tonnes_force_per_square_meter: float):
        """
        Create a new instance of Pressure from a value in tonnes_force_per_square_meter.

        

        :param meters: The Pressure value in tonnes_force_per_square_meter.
        :type tonnes_force_per_square_meter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(tonnes_force_per_square_meter, PressureUnits.TonneForcePerSquareMeter)

    
    @staticmethod
    def from_meters_of_head(meters_of_head: float):
        """
        Create a new instance of Pressure from a value in meters_of_head.

        

        :param meters: The Pressure value in meters_of_head.
        :type meters_of_head: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(meters_of_head, PressureUnits.MeterOfHead)

    
    @staticmethod
    def from_tonnes_force_per_square_centimeter(tonnes_force_per_square_centimeter: float):
        """
        Create a new instance of Pressure from a value in tonnes_force_per_square_centimeter.

        

        :param meters: The Pressure value in tonnes_force_per_square_centimeter.
        :type tonnes_force_per_square_centimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(tonnes_force_per_square_centimeter, PressureUnits.TonneForcePerSquareCentimeter)

    
    @staticmethod
    def from_feet_of_head(feet_of_head: float):
        """
        Create a new instance of Pressure from a value in feet_of_head.

        

        :param meters: The Pressure value in feet_of_head.
        :type feet_of_head: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(feet_of_head, PressureUnits.FootOfHead)

    
    @staticmethod
    def from_millimeters_of_mercury(millimeters_of_mercury: float):
        """
        Create a new instance of Pressure from a value in millimeters_of_mercury.

        

        :param meters: The Pressure value in millimeters_of_mercury.
        :type millimeters_of_mercury: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(millimeters_of_mercury, PressureUnits.MillimeterOfMercury)

    
    @staticmethod
    def from_inches_of_mercury(inches_of_mercury: float):
        """
        Create a new instance of Pressure from a value in inches_of_mercury.

        

        :param meters: The Pressure value in inches_of_mercury.
        :type inches_of_mercury: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(inches_of_mercury, PressureUnits.InchOfMercury)

    
    @staticmethod
    def from_dynes_per_square_centimeter(dynes_per_square_centimeter: float):
        """
        Create a new instance of Pressure from a value in dynes_per_square_centimeter.

        

        :param meters: The Pressure value in dynes_per_square_centimeter.
        :type dynes_per_square_centimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(dynes_per_square_centimeter, PressureUnits.DynePerSquareCentimeter)

    
    @staticmethod
    def from_pounds_per_inch_second_squared(pounds_per_inch_second_squared: float):
        """
        Create a new instance of Pressure from a value in pounds_per_inch_second_squared.

        

        :param meters: The Pressure value in pounds_per_inch_second_squared.
        :type pounds_per_inch_second_squared: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(pounds_per_inch_second_squared, PressureUnits.PoundPerInchSecondSquared)

    
    @staticmethod
    def from_meters_of_water_column(meters_of_water_column: float):
        """
        Create a new instance of Pressure from a value in meters_of_water_column.

        

        :param meters: The Pressure value in meters_of_water_column.
        :type meters_of_water_column: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(meters_of_water_column, PressureUnits.MeterOfWaterColumn)

    
    @staticmethod
    def from_inches_of_water_column(inches_of_water_column: float):
        """
        Create a new instance of Pressure from a value in inches_of_water_column.

        

        :param meters: The Pressure value in inches_of_water_column.
        :type inches_of_water_column: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(inches_of_water_column, PressureUnits.InchOfWaterColumn)

    
    @staticmethod
    def from_meters_of_elevation(meters_of_elevation: float):
        """
        Create a new instance of Pressure from a value in meters_of_elevation.

        

        :param meters: The Pressure value in meters_of_elevation.
        :type meters_of_elevation: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(meters_of_elevation, PressureUnits.MeterOfElevation)

    
    @staticmethod
    def from_feet_of_elevation(feet_of_elevation: float):
        """
        Create a new instance of Pressure from a value in feet_of_elevation.

        

        :param meters: The Pressure value in feet_of_elevation.
        :type feet_of_elevation: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(feet_of_elevation, PressureUnits.FootOfElevation)

    
    @staticmethod
    def from_micropascals(micropascals: float):
        """
        Create a new instance of Pressure from a value in micropascals.

        

        :param meters: The Pressure value in micropascals.
        :type micropascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(micropascals, PressureUnits.Micropascal)

    
    @staticmethod
    def from_millipascals(millipascals: float):
        """
        Create a new instance of Pressure from a value in millipascals.

        

        :param meters: The Pressure value in millipascals.
        :type millipascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(millipascals, PressureUnits.Millipascal)

    
    @staticmethod
    def from_decapascals(decapascals: float):
        """
        Create a new instance of Pressure from a value in decapascals.

        

        :param meters: The Pressure value in decapascals.
        :type decapascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(decapascals, PressureUnits.Decapascal)

    
    @staticmethod
    def from_hectopascals(hectopascals: float):
        """
        Create a new instance of Pressure from a value in hectopascals.

        

        :param meters: The Pressure value in hectopascals.
        :type hectopascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(hectopascals, PressureUnits.Hectopascal)

    
    @staticmethod
    def from_kilopascals(kilopascals: float):
        """
        Create a new instance of Pressure from a value in kilopascals.

        

        :param meters: The Pressure value in kilopascals.
        :type kilopascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilopascals, PressureUnits.Kilopascal)

    
    @staticmethod
    def from_megapascals(megapascals: float):
        """
        Create a new instance of Pressure from a value in megapascals.

        

        :param meters: The Pressure value in megapascals.
        :type megapascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(megapascals, PressureUnits.Megapascal)

    
    @staticmethod
    def from_gigapascals(gigapascals: float):
        """
        Create a new instance of Pressure from a value in gigapascals.

        

        :param meters: The Pressure value in gigapascals.
        :type gigapascals: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(gigapascals, PressureUnits.Gigapascal)

    
    @staticmethod
    def from_microbars(microbars: float):
        """
        Create a new instance of Pressure from a value in microbars.

        

        :param meters: The Pressure value in microbars.
        :type microbars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(microbars, PressureUnits.Microbar)

    
    @staticmethod
    def from_millibars(millibars: float):
        """
        Create a new instance of Pressure from a value in millibars.

        

        :param meters: The Pressure value in millibars.
        :type millibars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(millibars, PressureUnits.Millibar)

    
    @staticmethod
    def from_centibars(centibars: float):
        """
        Create a new instance of Pressure from a value in centibars.

        

        :param meters: The Pressure value in centibars.
        :type centibars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(centibars, PressureUnits.Centibar)

    
    @staticmethod
    def from_decibars(decibars: float):
        """
        Create a new instance of Pressure from a value in decibars.

        

        :param meters: The Pressure value in decibars.
        :type decibars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(decibars, PressureUnits.Decibar)

    
    @staticmethod
    def from_kilobars(kilobars: float):
        """
        Create a new instance of Pressure from a value in kilobars.

        

        :param meters: The Pressure value in kilobars.
        :type kilobars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilobars, PressureUnits.Kilobar)

    
    @staticmethod
    def from_megabars(megabars: float):
        """
        Create a new instance of Pressure from a value in megabars.

        

        :param meters: The Pressure value in megabars.
        :type megabars: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(megabars, PressureUnits.Megabar)

    
    @staticmethod
    def from_kilonewtons_per_square_meter(kilonewtons_per_square_meter: float):
        """
        Create a new instance of Pressure from a value in kilonewtons_per_square_meter.

        

        :param meters: The Pressure value in kilonewtons_per_square_meter.
        :type kilonewtons_per_square_meter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilonewtons_per_square_meter, PressureUnits.KilonewtonPerSquareMeter)

    
    @staticmethod
    def from_meganewtons_per_square_meter(meganewtons_per_square_meter: float):
        """
        Create a new instance of Pressure from a value in meganewtons_per_square_meter.

        

        :param meters: The Pressure value in meganewtons_per_square_meter.
        :type meganewtons_per_square_meter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(meganewtons_per_square_meter, PressureUnits.MeganewtonPerSquareMeter)

    
    @staticmethod
    def from_kilonewtons_per_square_centimeter(kilonewtons_per_square_centimeter: float):
        """
        Create a new instance of Pressure from a value in kilonewtons_per_square_centimeter.

        

        :param meters: The Pressure value in kilonewtons_per_square_centimeter.
        :type kilonewtons_per_square_centimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilonewtons_per_square_centimeter, PressureUnits.KilonewtonPerSquareCentimeter)

    
    @staticmethod
    def from_kilonewtons_per_square_millimeter(kilonewtons_per_square_millimeter: float):
        """
        Create a new instance of Pressure from a value in kilonewtons_per_square_millimeter.

        

        :param meters: The Pressure value in kilonewtons_per_square_millimeter.
        :type kilonewtons_per_square_millimeter: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilonewtons_per_square_millimeter, PressureUnits.KilonewtonPerSquareMillimeter)

    
    @staticmethod
    def from_kilopounds_force_per_square_inch(kilopounds_force_per_square_inch: float):
        """
        Create a new instance of Pressure from a value in kilopounds_force_per_square_inch.

        

        :param meters: The Pressure value in kilopounds_force_per_square_inch.
        :type kilopounds_force_per_square_inch: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilopounds_force_per_square_inch, PressureUnits.KilopoundForcePerSquareInch)

    
    @staticmethod
    def from_kilopounds_force_per_square_mil(kilopounds_force_per_square_mil: float):
        """
        Create a new instance of Pressure from a value in kilopounds_force_per_square_mil.

        

        :param meters: The Pressure value in kilopounds_force_per_square_mil.
        :type kilopounds_force_per_square_mil: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilopounds_force_per_square_mil, PressureUnits.KilopoundForcePerSquareMil)

    
    @staticmethod
    def from_kilopounds_force_per_square_foot(kilopounds_force_per_square_foot: float):
        """
        Create a new instance of Pressure from a value in kilopounds_force_per_square_foot.

        

        :param meters: The Pressure value in kilopounds_force_per_square_foot.
        :type kilopounds_force_per_square_foot: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(kilopounds_force_per_square_foot, PressureUnits.KilopoundForcePerSquareFoot)

    
    @staticmethod
    def from_millimeters_of_water_column(millimeters_of_water_column: float):
        """
        Create a new instance of Pressure from a value in millimeters_of_water_column.

        

        :param meters: The Pressure value in millimeters_of_water_column.
        :type millimeters_of_water_column: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(millimeters_of_water_column, PressureUnits.MillimeterOfWaterColumn)

    
    @staticmethod
    def from_centimeters_of_water_column(centimeters_of_water_column: float):
        """
        Create a new instance of Pressure from a value in centimeters_of_water_column.

        

        :param meters: The Pressure value in centimeters_of_water_column.
        :type centimeters_of_water_column: float
        :return: A new instance of Pressure.
        :rtype: Pressure
        """
        return Pressure(centimeters_of_water_column, PressureUnits.CentimeterOfWaterColumn)

    
    @property
    def pascals(self) -> float:
        """
        
        """
        if self.__pascals != None:
            return self.__pascals
        self.__pascals = self.__convert_from_base(PressureUnits.Pascal)
        return self.__pascals

    
    @property
    def atmospheres(self) -> float:
        """
        
        """
        if self.__atmospheres != None:
            return self.__atmospheres
        self.__atmospheres = self.__convert_from_base(PressureUnits.Atmosphere)
        return self.__atmospheres

    
    @property
    def bars(self) -> float:
        """
        
        """
        if self.__bars != None:
            return self.__bars
        self.__bars = self.__convert_from_base(PressureUnits.Bar)
        return self.__bars

    
    @property
    def kilograms_force_per_square_meter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_square_meter != None:
            return self.__kilograms_force_per_square_meter
        self.__kilograms_force_per_square_meter = self.__convert_from_base(PressureUnits.KilogramForcePerSquareMeter)
        return self.__kilograms_force_per_square_meter

    
    @property
    def kilograms_force_per_square_centimeter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_square_centimeter != None:
            return self.__kilograms_force_per_square_centimeter
        self.__kilograms_force_per_square_centimeter = self.__convert_from_base(PressureUnits.KilogramForcePerSquareCentimeter)
        return self.__kilograms_force_per_square_centimeter

    
    @property
    def kilograms_force_per_square_millimeter(self) -> float:
        """
        
        """
        if self.__kilograms_force_per_square_millimeter != None:
            return self.__kilograms_force_per_square_millimeter
        self.__kilograms_force_per_square_millimeter = self.__convert_from_base(PressureUnits.KilogramForcePerSquareMillimeter)
        return self.__kilograms_force_per_square_millimeter

    
    @property
    def newtons_per_square_meter(self) -> float:
        """
        
        """
        if self.__newtons_per_square_meter != None:
            return self.__newtons_per_square_meter
        self.__newtons_per_square_meter = self.__convert_from_base(PressureUnits.NewtonPerSquareMeter)
        return self.__newtons_per_square_meter

    
    @property
    def newtons_per_square_centimeter(self) -> float:
        """
        
        """
        if self.__newtons_per_square_centimeter != None:
            return self.__newtons_per_square_centimeter
        self.__newtons_per_square_centimeter = self.__convert_from_base(PressureUnits.NewtonPerSquareCentimeter)
        return self.__newtons_per_square_centimeter

    
    @property
    def newtons_per_square_millimeter(self) -> float:
        """
        
        """
        if self.__newtons_per_square_millimeter != None:
            return self.__newtons_per_square_millimeter
        self.__newtons_per_square_millimeter = self.__convert_from_base(PressureUnits.NewtonPerSquareMillimeter)
        return self.__newtons_per_square_millimeter

    
    @property
    def technical_atmospheres(self) -> float:
        """
        
        """
        if self.__technical_atmospheres != None:
            return self.__technical_atmospheres
        self.__technical_atmospheres = self.__convert_from_base(PressureUnits.TechnicalAtmosphere)
        return self.__technical_atmospheres

    
    @property
    def torrs(self) -> float:
        """
        
        """
        if self.__torrs != None:
            return self.__torrs
        self.__torrs = self.__convert_from_base(PressureUnits.Torr)
        return self.__torrs

    
    @property
    def pounds_force_per_square_inch(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_inch != None:
            return self.__pounds_force_per_square_inch
        self.__pounds_force_per_square_inch = self.__convert_from_base(PressureUnits.PoundForcePerSquareInch)
        return self.__pounds_force_per_square_inch

    
    @property
    def pounds_force_per_square_mil(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_mil != None:
            return self.__pounds_force_per_square_mil
        self.__pounds_force_per_square_mil = self.__convert_from_base(PressureUnits.PoundForcePerSquareMil)
        return self.__pounds_force_per_square_mil

    
    @property
    def pounds_force_per_square_foot(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_foot != None:
            return self.__pounds_force_per_square_foot
        self.__pounds_force_per_square_foot = self.__convert_from_base(PressureUnits.PoundForcePerSquareFoot)
        return self.__pounds_force_per_square_foot

    
    @property
    def tonnes_force_per_square_millimeter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_square_millimeter != None:
            return self.__tonnes_force_per_square_millimeter
        self.__tonnes_force_per_square_millimeter = self.__convert_from_base(PressureUnits.TonneForcePerSquareMillimeter)
        return self.__tonnes_force_per_square_millimeter

    
    @property
    def tonnes_force_per_square_meter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_square_meter != None:
            return self.__tonnes_force_per_square_meter
        self.__tonnes_force_per_square_meter = self.__convert_from_base(PressureUnits.TonneForcePerSquareMeter)
        return self.__tonnes_force_per_square_meter

    
    @property
    def meters_of_head(self) -> float:
        """
        
        """
        if self.__meters_of_head != None:
            return self.__meters_of_head
        self.__meters_of_head = self.__convert_from_base(PressureUnits.MeterOfHead)
        return self.__meters_of_head

    
    @property
    def tonnes_force_per_square_centimeter(self) -> float:
        """
        
        """
        if self.__tonnes_force_per_square_centimeter != None:
            return self.__tonnes_force_per_square_centimeter
        self.__tonnes_force_per_square_centimeter = self.__convert_from_base(PressureUnits.TonneForcePerSquareCentimeter)
        return self.__tonnes_force_per_square_centimeter

    
    @property
    def feet_of_head(self) -> float:
        """
        
        """
        if self.__feet_of_head != None:
            return self.__feet_of_head
        self.__feet_of_head = self.__convert_from_base(PressureUnits.FootOfHead)
        return self.__feet_of_head

    
    @property
    def millimeters_of_mercury(self) -> float:
        """
        
        """
        if self.__millimeters_of_mercury != None:
            return self.__millimeters_of_mercury
        self.__millimeters_of_mercury = self.__convert_from_base(PressureUnits.MillimeterOfMercury)
        return self.__millimeters_of_mercury

    
    @property
    def inches_of_mercury(self) -> float:
        """
        
        """
        if self.__inches_of_mercury != None:
            return self.__inches_of_mercury
        self.__inches_of_mercury = self.__convert_from_base(PressureUnits.InchOfMercury)
        return self.__inches_of_mercury

    
    @property
    def dynes_per_square_centimeter(self) -> float:
        """
        
        """
        if self.__dynes_per_square_centimeter != None:
            return self.__dynes_per_square_centimeter
        self.__dynes_per_square_centimeter = self.__convert_from_base(PressureUnits.DynePerSquareCentimeter)
        return self.__dynes_per_square_centimeter

    
    @property
    def pounds_per_inch_second_squared(self) -> float:
        """
        
        """
        if self.__pounds_per_inch_second_squared != None:
            return self.__pounds_per_inch_second_squared
        self.__pounds_per_inch_second_squared = self.__convert_from_base(PressureUnits.PoundPerInchSecondSquared)
        return self.__pounds_per_inch_second_squared

    
    @property
    def meters_of_water_column(self) -> float:
        """
        
        """
        if self.__meters_of_water_column != None:
            return self.__meters_of_water_column
        self.__meters_of_water_column = self.__convert_from_base(PressureUnits.MeterOfWaterColumn)
        return self.__meters_of_water_column

    
    @property
    def inches_of_water_column(self) -> float:
        """
        
        """
        if self.__inches_of_water_column != None:
            return self.__inches_of_water_column
        self.__inches_of_water_column = self.__convert_from_base(PressureUnits.InchOfWaterColumn)
        return self.__inches_of_water_column

    
    @property
    def meters_of_elevation(self) -> float:
        """
        
        """
        if self.__meters_of_elevation != None:
            return self.__meters_of_elevation
        self.__meters_of_elevation = self.__convert_from_base(PressureUnits.MeterOfElevation)
        return self.__meters_of_elevation

    
    @property
    def feet_of_elevation(self) -> float:
        """
        
        """
        if self.__feet_of_elevation != None:
            return self.__feet_of_elevation
        self.__feet_of_elevation = self.__convert_from_base(PressureUnits.FootOfElevation)
        return self.__feet_of_elevation

    
    @property
    def micropascals(self) -> float:
        """
        
        """
        if self.__micropascals != None:
            return self.__micropascals
        self.__micropascals = self.__convert_from_base(PressureUnits.Micropascal)
        return self.__micropascals

    
    @property
    def millipascals(self) -> float:
        """
        
        """
        if self.__millipascals != None:
            return self.__millipascals
        self.__millipascals = self.__convert_from_base(PressureUnits.Millipascal)
        return self.__millipascals

    
    @property
    def decapascals(self) -> float:
        """
        
        """
        if self.__decapascals != None:
            return self.__decapascals
        self.__decapascals = self.__convert_from_base(PressureUnits.Decapascal)
        return self.__decapascals

    
    @property
    def hectopascals(self) -> float:
        """
        
        """
        if self.__hectopascals != None:
            return self.__hectopascals
        self.__hectopascals = self.__convert_from_base(PressureUnits.Hectopascal)
        return self.__hectopascals

    
    @property
    def kilopascals(self) -> float:
        """
        
        """
        if self.__kilopascals != None:
            return self.__kilopascals
        self.__kilopascals = self.__convert_from_base(PressureUnits.Kilopascal)
        return self.__kilopascals

    
    @property
    def megapascals(self) -> float:
        """
        
        """
        if self.__megapascals != None:
            return self.__megapascals
        self.__megapascals = self.__convert_from_base(PressureUnits.Megapascal)
        return self.__megapascals

    
    @property
    def gigapascals(self) -> float:
        """
        
        """
        if self.__gigapascals != None:
            return self.__gigapascals
        self.__gigapascals = self.__convert_from_base(PressureUnits.Gigapascal)
        return self.__gigapascals

    
    @property
    def microbars(self) -> float:
        """
        
        """
        if self.__microbars != None:
            return self.__microbars
        self.__microbars = self.__convert_from_base(PressureUnits.Microbar)
        return self.__microbars

    
    @property
    def millibars(self) -> float:
        """
        
        """
        if self.__millibars != None:
            return self.__millibars
        self.__millibars = self.__convert_from_base(PressureUnits.Millibar)
        return self.__millibars

    
    @property
    def centibars(self) -> float:
        """
        
        """
        if self.__centibars != None:
            return self.__centibars
        self.__centibars = self.__convert_from_base(PressureUnits.Centibar)
        return self.__centibars

    
    @property
    def decibars(self) -> float:
        """
        
        """
        if self.__decibars != None:
            return self.__decibars
        self.__decibars = self.__convert_from_base(PressureUnits.Decibar)
        return self.__decibars

    
    @property
    def kilobars(self) -> float:
        """
        
        """
        if self.__kilobars != None:
            return self.__kilobars
        self.__kilobars = self.__convert_from_base(PressureUnits.Kilobar)
        return self.__kilobars

    
    @property
    def megabars(self) -> float:
        """
        
        """
        if self.__megabars != None:
            return self.__megabars
        self.__megabars = self.__convert_from_base(PressureUnits.Megabar)
        return self.__megabars

    
    @property
    def kilonewtons_per_square_meter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_square_meter != None:
            return self.__kilonewtons_per_square_meter
        self.__kilonewtons_per_square_meter = self.__convert_from_base(PressureUnits.KilonewtonPerSquareMeter)
        return self.__kilonewtons_per_square_meter

    
    @property
    def meganewtons_per_square_meter(self) -> float:
        """
        
        """
        if self.__meganewtons_per_square_meter != None:
            return self.__meganewtons_per_square_meter
        self.__meganewtons_per_square_meter = self.__convert_from_base(PressureUnits.MeganewtonPerSquareMeter)
        return self.__meganewtons_per_square_meter

    
    @property
    def kilonewtons_per_square_centimeter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_square_centimeter != None:
            return self.__kilonewtons_per_square_centimeter
        self.__kilonewtons_per_square_centimeter = self.__convert_from_base(PressureUnits.KilonewtonPerSquareCentimeter)
        return self.__kilonewtons_per_square_centimeter

    
    @property
    def kilonewtons_per_square_millimeter(self) -> float:
        """
        
        """
        if self.__kilonewtons_per_square_millimeter != None:
            return self.__kilonewtons_per_square_millimeter
        self.__kilonewtons_per_square_millimeter = self.__convert_from_base(PressureUnits.KilonewtonPerSquareMillimeter)
        return self.__kilonewtons_per_square_millimeter

    
    @property
    def kilopounds_force_per_square_inch(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_inch != None:
            return self.__kilopounds_force_per_square_inch
        self.__kilopounds_force_per_square_inch = self.__convert_from_base(PressureUnits.KilopoundForcePerSquareInch)
        return self.__kilopounds_force_per_square_inch

    
    @property
    def kilopounds_force_per_square_mil(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_mil != None:
            return self.__kilopounds_force_per_square_mil
        self.__kilopounds_force_per_square_mil = self.__convert_from_base(PressureUnits.KilopoundForcePerSquareMil)
        return self.__kilopounds_force_per_square_mil

    
    @property
    def kilopounds_force_per_square_foot(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_foot != None:
            return self.__kilopounds_force_per_square_foot
        self.__kilopounds_force_per_square_foot = self.__convert_from_base(PressureUnits.KilopoundForcePerSquareFoot)
        return self.__kilopounds_force_per_square_foot

    
    @property
    def millimeters_of_water_column(self) -> float:
        """
        
        """
        if self.__millimeters_of_water_column != None:
            return self.__millimeters_of_water_column
        self.__millimeters_of_water_column = self.__convert_from_base(PressureUnits.MillimeterOfWaterColumn)
        return self.__millimeters_of_water_column

    
    @property
    def centimeters_of_water_column(self) -> float:
        """
        
        """
        if self.__centimeters_of_water_column != None:
            return self.__centimeters_of_water_column
        self.__centimeters_of_water_column = self.__convert_from_base(PressureUnits.CentimeterOfWaterColumn)
        return self.__centimeters_of_water_column

    
    def to_string(self, unit: PressureUnits = PressureUnits.Pascal) -> string:
        """
        Format the Pressure to string.
        Note! the default format for Pressure is Pascal.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == PressureUnits.Pascal:
            return f"""{self.pascals} Pa"""
        
        if unit == PressureUnits.Atmosphere:
            return f"""{self.atmospheres} atm"""
        
        if unit == PressureUnits.Bar:
            return f"""{self.bars} bar"""
        
        if unit == PressureUnits.KilogramForcePerSquareMeter:
            return f"""{self.kilograms_force_per_square_meter} kgf/m²"""
        
        if unit == PressureUnits.KilogramForcePerSquareCentimeter:
            return f"""{self.kilograms_force_per_square_centimeter} kgf/cm²"""
        
        if unit == PressureUnits.KilogramForcePerSquareMillimeter:
            return f"""{self.kilograms_force_per_square_millimeter} kgf/mm²"""
        
        if unit == PressureUnits.NewtonPerSquareMeter:
            return f"""{self.newtons_per_square_meter} N/m²"""
        
        if unit == PressureUnits.NewtonPerSquareCentimeter:
            return f"""{self.newtons_per_square_centimeter} N/cm²"""
        
        if unit == PressureUnits.NewtonPerSquareMillimeter:
            return f"""{self.newtons_per_square_millimeter} N/mm²"""
        
        if unit == PressureUnits.TechnicalAtmosphere:
            return f"""{self.technical_atmospheres} at"""
        
        if unit == PressureUnits.Torr:
            return f"""{self.torrs} torr"""
        
        if unit == PressureUnits.PoundForcePerSquareInch:
            return f"""{self.pounds_force_per_square_inch} psi"""
        
        if unit == PressureUnits.PoundForcePerSquareMil:
            return f"""{self.pounds_force_per_square_mil} lb/mil²"""
        
        if unit == PressureUnits.PoundForcePerSquareFoot:
            return f"""{self.pounds_force_per_square_foot} lb/ft²"""
        
        if unit == PressureUnits.TonneForcePerSquareMillimeter:
            return f"""{self.tonnes_force_per_square_millimeter} tf/mm²"""
        
        if unit == PressureUnits.TonneForcePerSquareMeter:
            return f"""{self.tonnes_force_per_square_meter} tf/m²"""
        
        if unit == PressureUnits.MeterOfHead:
            return f"""{self.meters_of_head} m of head"""
        
        if unit == PressureUnits.TonneForcePerSquareCentimeter:
            return f"""{self.tonnes_force_per_square_centimeter} tf/cm²"""
        
        if unit == PressureUnits.FootOfHead:
            return f"""{self.feet_of_head} ft of head"""
        
        if unit == PressureUnits.MillimeterOfMercury:
            return f"""{self.millimeters_of_mercury} mmHg"""
        
        if unit == PressureUnits.InchOfMercury:
            return f"""{self.inches_of_mercury} inHg"""
        
        if unit == PressureUnits.DynePerSquareCentimeter:
            return f"""{self.dynes_per_square_centimeter} dyn/cm²"""
        
        if unit == PressureUnits.PoundPerInchSecondSquared:
            return f"""{self.pounds_per_inch_second_squared} lbm/(in·s²)"""
        
        if unit == PressureUnits.MeterOfWaterColumn:
            return f"""{self.meters_of_water_column} mH₂O"""
        
        if unit == PressureUnits.InchOfWaterColumn:
            return f"""{self.inches_of_water_column} inH2O"""
        
        if unit == PressureUnits.MeterOfElevation:
            return f"""{self.meters_of_elevation} m of elevation"""
        
        if unit == PressureUnits.FootOfElevation:
            return f"""{self.feet_of_elevation} ft of elevation"""
        
        if unit == PressureUnits.Micropascal:
            return f"""{self.micropascals} """
        
        if unit == PressureUnits.Millipascal:
            return f"""{self.millipascals} """
        
        if unit == PressureUnits.Decapascal:
            return f"""{self.decapascals} """
        
        if unit == PressureUnits.Hectopascal:
            return f"""{self.hectopascals} """
        
        if unit == PressureUnits.Kilopascal:
            return f"""{self.kilopascals} """
        
        if unit == PressureUnits.Megapascal:
            return f"""{self.megapascals} """
        
        if unit == PressureUnits.Gigapascal:
            return f"""{self.gigapascals} """
        
        if unit == PressureUnits.Microbar:
            return f"""{self.microbars} """
        
        if unit == PressureUnits.Millibar:
            return f"""{self.millibars} """
        
        if unit == PressureUnits.Centibar:
            return f"""{self.centibars} """
        
        if unit == PressureUnits.Decibar:
            return f"""{self.decibars} """
        
        if unit == PressureUnits.Kilobar:
            return f"""{self.kilobars} """
        
        if unit == PressureUnits.Megabar:
            return f"""{self.megabars} """
        
        if unit == PressureUnits.KilonewtonPerSquareMeter:
            return f"""{self.kilonewtons_per_square_meter} """
        
        if unit == PressureUnits.MeganewtonPerSquareMeter:
            return f"""{self.meganewtons_per_square_meter} """
        
        if unit == PressureUnits.KilonewtonPerSquareCentimeter:
            return f"""{self.kilonewtons_per_square_centimeter} """
        
        if unit == PressureUnits.KilonewtonPerSquareMillimeter:
            return f"""{self.kilonewtons_per_square_millimeter} """
        
        if unit == PressureUnits.KilopoundForcePerSquareInch:
            return f"""{self.kilopounds_force_per_square_inch} """
        
        if unit == PressureUnits.KilopoundForcePerSquareMil:
            return f"""{self.kilopounds_force_per_square_mil} """
        
        if unit == PressureUnits.KilopoundForcePerSquareFoot:
            return f"""{self.kilopounds_force_per_square_foot} """
        
        if unit == PressureUnits.MillimeterOfWaterColumn:
            return f"""{self.millimeters_of_water_column} """
        
        if unit == PressureUnits.CentimeterOfWaterColumn:
            return f"""{self.centimeters_of_water_column} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: PressureUnits = PressureUnits.Pascal) -> string:
        """
        Get Pressure unit abbreviation.
        Note! the default abbreviation for Pressure is Pascal.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == PressureUnits.Pascal:
            return """Pa"""
        
        if unit_abbreviation == PressureUnits.Atmosphere:
            return """atm"""
        
        if unit_abbreviation == PressureUnits.Bar:
            return """bar"""
        
        if unit_abbreviation == PressureUnits.KilogramForcePerSquareMeter:
            return """kgf/m²"""
        
        if unit_abbreviation == PressureUnits.KilogramForcePerSquareCentimeter:
            return """kgf/cm²"""
        
        if unit_abbreviation == PressureUnits.KilogramForcePerSquareMillimeter:
            return """kgf/mm²"""
        
        if unit_abbreviation == PressureUnits.NewtonPerSquareMeter:
            return """N/m²"""
        
        if unit_abbreviation == PressureUnits.NewtonPerSquareCentimeter:
            return """N/cm²"""
        
        if unit_abbreviation == PressureUnits.NewtonPerSquareMillimeter:
            return """N/mm²"""
        
        if unit_abbreviation == PressureUnits.TechnicalAtmosphere:
            return """at"""
        
        if unit_abbreviation == PressureUnits.Torr:
            return """torr"""
        
        if unit_abbreviation == PressureUnits.PoundForcePerSquareInch:
            return """psi"""
        
        if unit_abbreviation == PressureUnits.PoundForcePerSquareMil:
            return """lb/mil²"""
        
        if unit_abbreviation == PressureUnits.PoundForcePerSquareFoot:
            return """lb/ft²"""
        
        if unit_abbreviation == PressureUnits.TonneForcePerSquareMillimeter:
            return """tf/mm²"""
        
        if unit_abbreviation == PressureUnits.TonneForcePerSquareMeter:
            return """tf/m²"""
        
        if unit_abbreviation == PressureUnits.MeterOfHead:
            return """m of head"""
        
        if unit_abbreviation == PressureUnits.TonneForcePerSquareCentimeter:
            return """tf/cm²"""
        
        if unit_abbreviation == PressureUnits.FootOfHead:
            return """ft of head"""
        
        if unit_abbreviation == PressureUnits.MillimeterOfMercury:
            return """mmHg"""
        
        if unit_abbreviation == PressureUnits.InchOfMercury:
            return """inHg"""
        
        if unit_abbreviation == PressureUnits.DynePerSquareCentimeter:
            return """dyn/cm²"""
        
        if unit_abbreviation == PressureUnits.PoundPerInchSecondSquared:
            return """lbm/(in·s²)"""
        
        if unit_abbreviation == PressureUnits.MeterOfWaterColumn:
            return """mH₂O"""
        
        if unit_abbreviation == PressureUnits.InchOfWaterColumn:
            return """inH2O"""
        
        if unit_abbreviation == PressureUnits.MeterOfElevation:
            return """m of elevation"""
        
        if unit_abbreviation == PressureUnits.FootOfElevation:
            return """ft of elevation"""
        
        if unit_abbreviation == PressureUnits.Micropascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Millipascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Decapascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Hectopascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Kilopascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Megapascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Gigapascal:
            return """"""
        
        if unit_abbreviation == PressureUnits.Microbar:
            return """"""
        
        if unit_abbreviation == PressureUnits.Millibar:
            return """"""
        
        if unit_abbreviation == PressureUnits.Centibar:
            return """"""
        
        if unit_abbreviation == PressureUnits.Decibar:
            return """"""
        
        if unit_abbreviation == PressureUnits.Kilobar:
            return """"""
        
        if unit_abbreviation == PressureUnits.Megabar:
            return """"""
        
        if unit_abbreviation == PressureUnits.KilonewtonPerSquareMeter:
            return """"""
        
        if unit_abbreviation == PressureUnits.MeganewtonPerSquareMeter:
            return """"""
        
        if unit_abbreviation == PressureUnits.KilonewtonPerSquareCentimeter:
            return """"""
        
        if unit_abbreviation == PressureUnits.KilonewtonPerSquareMillimeter:
            return """"""
        
        if unit_abbreviation == PressureUnits.KilopoundForcePerSquareInch:
            return """"""
        
        if unit_abbreviation == PressureUnits.KilopoundForcePerSquareMil:
            return """"""
        
        if unit_abbreviation == PressureUnits.KilopoundForcePerSquareFoot:
            return """"""
        
        if unit_abbreviation == PressureUnits.MillimeterOfWaterColumn:
            return """"""
        
        if unit_abbreviation == PressureUnits.CentimeterOfWaterColumn:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for +: 'Pressure' and '{}'".format(type(other).__name__))
        return Pressure(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for *: 'Pressure' and '{}'".format(type(other).__name__))
        return Pressure(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for -: 'Pressure' and '{}'".format(type(other).__name__))
        return Pressure(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for /: 'Pressure' and '{}'".format(type(other).__name__))
        return Pressure(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for %: 'Pressure' and '{}'".format(type(other).__name__))
        return Pressure(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for **: 'Pressure' and '{}'".format(type(other).__name__))
        return Pressure(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for ==: 'Pressure' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for <: 'Pressure' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for >: 'Pressure' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for <=: 'Pressure' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Pressure):
            raise TypeError("unsupported operand type(s) for >=: 'Pressure' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricChargeUnits(Enum):
        """
            ElectricChargeUnits enumeration
        """
        
        Coulomb = 'coulomb'
        """
            
        """
        
        AmpereHour = 'ampere_hour'
        """
            
        """
        
        Picocoulomb = 'picocoulomb'
        """
            
        """
        
        Nanocoulomb = 'nanocoulomb'
        """
            
        """
        
        Microcoulomb = 'microcoulomb'
        """
            
        """
        
        Millicoulomb = 'millicoulomb'
        """
            
        """
        
        Kilocoulomb = 'kilocoulomb'
        """
            
        """
        
        Megacoulomb = 'megacoulomb'
        """
            
        """
        
        MilliampereHour = 'milliampere_hour'
        """
            
        """
        
        KiloampereHour = 'kiloampere_hour'
        """
            
        """
        
        MegaampereHour = 'megaampere_hour'
        """
            
        """
        

class ElectricCharge:
    """
    Electric charge is the physical property of matter that causes it to experience a force when placed in an electromagnetic field.

    Args:
        value (float): The value.
        from_unit (ElectricChargeUnits): The ElectricCharge unit to create from, The default unit is Coulomb
    """
    def __init__(self, value: float, from_unit: ElectricChargeUnits = ElectricChargeUnits.Coulomb):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__coulombs = None
        
        self.__ampere_hours = None
        
        self.__picocoulombs = None
        
        self.__nanocoulombs = None
        
        self.__microcoulombs = None
        
        self.__millicoulombs = None
        
        self.__kilocoulombs = None
        
        self.__megacoulombs = None
        
        self.__milliampere_hours = None
        
        self.__kiloampere_hours = None
        
        self.__megaampere_hours = None
        

    def __convert_from_base(self, from_unit: ElectricChargeUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricChargeUnits.Coulomb:
            return (value)
        
        if from_unit == ElectricChargeUnits.AmpereHour:
            return (value * 2.77777777777e-4)
        
        if from_unit == ElectricChargeUnits.Picocoulomb:
            return ((value) / 1e-12)
        
        if from_unit == ElectricChargeUnits.Nanocoulomb:
            return ((value) / 1e-09)
        
        if from_unit == ElectricChargeUnits.Microcoulomb:
            return ((value) / 1e-06)
        
        if from_unit == ElectricChargeUnits.Millicoulomb:
            return ((value) / 0.001)
        
        if from_unit == ElectricChargeUnits.Kilocoulomb:
            return ((value) / 1000.0)
        
        if from_unit == ElectricChargeUnits.Megacoulomb:
            return ((value) / 1000000.0)
        
        if from_unit == ElectricChargeUnits.MilliampereHour:
            return ((value * 2.77777777777e-4) / 0.001)
        
        if from_unit == ElectricChargeUnits.KiloampereHour:
            return ((value * 2.77777777777e-4) / 1000.0)
        
        if from_unit == ElectricChargeUnits.MegaampereHour:
            return ((value * 2.77777777777e-4) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricChargeUnits) -> float:
        
        if to_unit == ElectricChargeUnits.Coulomb:
            return (value)
        
        if to_unit == ElectricChargeUnits.AmpereHour:
            return (value / 2.77777777777e-4)
        
        if to_unit == ElectricChargeUnits.Picocoulomb:
            return ((value) * 1e-12)
        
        if to_unit == ElectricChargeUnits.Nanocoulomb:
            return ((value) * 1e-09)
        
        if to_unit == ElectricChargeUnits.Microcoulomb:
            return ((value) * 1e-06)
        
        if to_unit == ElectricChargeUnits.Millicoulomb:
            return ((value) * 0.001)
        
        if to_unit == ElectricChargeUnits.Kilocoulomb:
            return ((value) * 1000.0)
        
        if to_unit == ElectricChargeUnits.Megacoulomb:
            return ((value) * 1000000.0)
        
        if to_unit == ElectricChargeUnits.MilliampereHour:
            return ((value / 2.77777777777e-4) * 0.001)
        
        if to_unit == ElectricChargeUnits.KiloampereHour:
            return ((value / 2.77777777777e-4) * 1000.0)
        
        if to_unit == ElectricChargeUnits.MegaampereHour:
            return ((value / 2.77777777777e-4) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_coulombs(coulombs: float):
        """
        Create a new instance of ElectricCharge from a value in coulombs.

        

        :param meters: The ElectricCharge value in coulombs.
        :type coulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(coulombs, ElectricChargeUnits.Coulomb)

    
    @staticmethod
    def from_ampere_hours(ampere_hours: float):
        """
        Create a new instance of ElectricCharge from a value in ampere_hours.

        

        :param meters: The ElectricCharge value in ampere_hours.
        :type ampere_hours: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(ampere_hours, ElectricChargeUnits.AmpereHour)

    
    @staticmethod
    def from_picocoulombs(picocoulombs: float):
        """
        Create a new instance of ElectricCharge from a value in picocoulombs.

        

        :param meters: The ElectricCharge value in picocoulombs.
        :type picocoulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(picocoulombs, ElectricChargeUnits.Picocoulomb)

    
    @staticmethod
    def from_nanocoulombs(nanocoulombs: float):
        """
        Create a new instance of ElectricCharge from a value in nanocoulombs.

        

        :param meters: The ElectricCharge value in nanocoulombs.
        :type nanocoulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(nanocoulombs, ElectricChargeUnits.Nanocoulomb)

    
    @staticmethod
    def from_microcoulombs(microcoulombs: float):
        """
        Create a new instance of ElectricCharge from a value in microcoulombs.

        

        :param meters: The ElectricCharge value in microcoulombs.
        :type microcoulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(microcoulombs, ElectricChargeUnits.Microcoulomb)

    
    @staticmethod
    def from_millicoulombs(millicoulombs: float):
        """
        Create a new instance of ElectricCharge from a value in millicoulombs.

        

        :param meters: The ElectricCharge value in millicoulombs.
        :type millicoulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(millicoulombs, ElectricChargeUnits.Millicoulomb)

    
    @staticmethod
    def from_kilocoulombs(kilocoulombs: float):
        """
        Create a new instance of ElectricCharge from a value in kilocoulombs.

        

        :param meters: The ElectricCharge value in kilocoulombs.
        :type kilocoulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(kilocoulombs, ElectricChargeUnits.Kilocoulomb)

    
    @staticmethod
    def from_megacoulombs(megacoulombs: float):
        """
        Create a new instance of ElectricCharge from a value in megacoulombs.

        

        :param meters: The ElectricCharge value in megacoulombs.
        :type megacoulombs: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(megacoulombs, ElectricChargeUnits.Megacoulomb)

    
    @staticmethod
    def from_milliampere_hours(milliampere_hours: float):
        """
        Create a new instance of ElectricCharge from a value in milliampere_hours.

        

        :param meters: The ElectricCharge value in milliampere_hours.
        :type milliampere_hours: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(milliampere_hours, ElectricChargeUnits.MilliampereHour)

    
    @staticmethod
    def from_kiloampere_hours(kiloampere_hours: float):
        """
        Create a new instance of ElectricCharge from a value in kiloampere_hours.

        

        :param meters: The ElectricCharge value in kiloampere_hours.
        :type kiloampere_hours: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(kiloampere_hours, ElectricChargeUnits.KiloampereHour)

    
    @staticmethod
    def from_megaampere_hours(megaampere_hours: float):
        """
        Create a new instance of ElectricCharge from a value in megaampere_hours.

        

        :param meters: The ElectricCharge value in megaampere_hours.
        :type megaampere_hours: float
        :return: A new instance of ElectricCharge.
        :rtype: ElectricCharge
        """
        return ElectricCharge(megaampere_hours, ElectricChargeUnits.MegaampereHour)

    
    @property
    def coulombs(self) -> float:
        """
        
        """
        if self.__coulombs != None:
            return self.__coulombs
        self.__coulombs = self.__convert_from_base(ElectricChargeUnits.Coulomb)
        return self.__coulombs

    
    @property
    def ampere_hours(self) -> float:
        """
        
        """
        if self.__ampere_hours != None:
            return self.__ampere_hours
        self.__ampere_hours = self.__convert_from_base(ElectricChargeUnits.AmpereHour)
        return self.__ampere_hours

    
    @property
    def picocoulombs(self) -> float:
        """
        
        """
        if self.__picocoulombs != None:
            return self.__picocoulombs
        self.__picocoulombs = self.__convert_from_base(ElectricChargeUnits.Picocoulomb)
        return self.__picocoulombs

    
    @property
    def nanocoulombs(self) -> float:
        """
        
        """
        if self.__nanocoulombs != None:
            return self.__nanocoulombs
        self.__nanocoulombs = self.__convert_from_base(ElectricChargeUnits.Nanocoulomb)
        return self.__nanocoulombs

    
    @property
    def microcoulombs(self) -> float:
        """
        
        """
        if self.__microcoulombs != None:
            return self.__microcoulombs
        self.__microcoulombs = self.__convert_from_base(ElectricChargeUnits.Microcoulomb)
        return self.__microcoulombs

    
    @property
    def millicoulombs(self) -> float:
        """
        
        """
        if self.__millicoulombs != None:
            return self.__millicoulombs
        self.__millicoulombs = self.__convert_from_base(ElectricChargeUnits.Millicoulomb)
        return self.__millicoulombs

    
    @property
    def kilocoulombs(self) -> float:
        """
        
        """
        if self.__kilocoulombs != None:
            return self.__kilocoulombs
        self.__kilocoulombs = self.__convert_from_base(ElectricChargeUnits.Kilocoulomb)
        return self.__kilocoulombs

    
    @property
    def megacoulombs(self) -> float:
        """
        
        """
        if self.__megacoulombs != None:
            return self.__megacoulombs
        self.__megacoulombs = self.__convert_from_base(ElectricChargeUnits.Megacoulomb)
        return self.__megacoulombs

    
    @property
    def milliampere_hours(self) -> float:
        """
        
        """
        if self.__milliampere_hours != None:
            return self.__milliampere_hours
        self.__milliampere_hours = self.__convert_from_base(ElectricChargeUnits.MilliampereHour)
        return self.__milliampere_hours

    
    @property
    def kiloampere_hours(self) -> float:
        """
        
        """
        if self.__kiloampere_hours != None:
            return self.__kiloampere_hours
        self.__kiloampere_hours = self.__convert_from_base(ElectricChargeUnits.KiloampereHour)
        return self.__kiloampere_hours

    
    @property
    def megaampere_hours(self) -> float:
        """
        
        """
        if self.__megaampere_hours != None:
            return self.__megaampere_hours
        self.__megaampere_hours = self.__convert_from_base(ElectricChargeUnits.MegaampereHour)
        return self.__megaampere_hours

    
    def to_string(self, unit: ElectricChargeUnits = ElectricChargeUnits.Coulomb) -> string:
        """
        Format the ElectricCharge to string.
        Note! the default format for ElectricCharge is Coulomb.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricChargeUnits.Coulomb:
            return f"""{self.coulombs} C"""
        
        if unit == ElectricChargeUnits.AmpereHour:
            return f"""{self.ampere_hours} A-h"""
        
        if unit == ElectricChargeUnits.Picocoulomb:
            return f"""{self.picocoulombs} """
        
        if unit == ElectricChargeUnits.Nanocoulomb:
            return f"""{self.nanocoulombs} """
        
        if unit == ElectricChargeUnits.Microcoulomb:
            return f"""{self.microcoulombs} """
        
        if unit == ElectricChargeUnits.Millicoulomb:
            return f"""{self.millicoulombs} """
        
        if unit == ElectricChargeUnits.Kilocoulomb:
            return f"""{self.kilocoulombs} """
        
        if unit == ElectricChargeUnits.Megacoulomb:
            return f"""{self.megacoulombs} """
        
        if unit == ElectricChargeUnits.MilliampereHour:
            return f"""{self.milliampere_hours} """
        
        if unit == ElectricChargeUnits.KiloampereHour:
            return f"""{self.kiloampere_hours} """
        
        if unit == ElectricChargeUnits.MegaampereHour:
            return f"""{self.megaampere_hours} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricChargeUnits = ElectricChargeUnits.Coulomb) -> string:
        """
        Get ElectricCharge unit abbreviation.
        Note! the default abbreviation for ElectricCharge is Coulomb.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricChargeUnits.Coulomb:
            return """C"""
        
        if unit_abbreviation == ElectricChargeUnits.AmpereHour:
            return """A-h"""
        
        if unit_abbreviation == ElectricChargeUnits.Picocoulomb:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.Nanocoulomb:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.Microcoulomb:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.Millicoulomb:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.Kilocoulomb:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.Megacoulomb:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.MilliampereHour:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.KiloampereHour:
            return """"""
        
        if unit_abbreviation == ElectricChargeUnits.MegaampereHour:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for +: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return ElectricCharge(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for *: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return ElectricCharge(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for -: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return ElectricCharge(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for /: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return ElectricCharge(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for %: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return ElectricCharge(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for **: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return ElectricCharge(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for <: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for >: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricCharge):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricCharge' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ReciprocalAreaUnits(Enum):
        """
            ReciprocalAreaUnits enumeration
        """
        
        InverseSquareMeter = 'inverse_square_meter'
        """
            
        """
        
        InverseSquareKilometer = 'inverse_square_kilometer'
        """
            
        """
        
        InverseSquareDecimeter = 'inverse_square_decimeter'
        """
            
        """
        
        InverseSquareCentimeter = 'inverse_square_centimeter'
        """
            
        """
        
        InverseSquareMillimeter = 'inverse_square_millimeter'
        """
            
        """
        
        InverseSquareMicrometer = 'inverse_square_micrometer'
        """
            
        """
        
        InverseSquareMile = 'inverse_square_mile'
        """
            
        """
        
        InverseSquareYard = 'inverse_square_yard'
        """
            
        """
        
        InverseSquareFoot = 'inverse_square_foot'
        """
            
        """
        
        InverseUsSurveySquareFoot = 'inverse_us_survey_square_foot'
        """
            
        """
        
        InverseSquareInch = 'inverse_square_inch'
        """
            
        """
        

class ReciprocalArea:
    """
    Reciprocal area (Inverse-square) quantity is used to specify a physical quantity inversely proportional to the square of the distance.

    Args:
        value (float): The value.
        from_unit (ReciprocalAreaUnits): The ReciprocalArea unit to create from, The default unit is InverseSquareMeter
    """
    def __init__(self, value: float, from_unit: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__inverse_square_meters = None
        
        self.__inverse_square_kilometers = None
        
        self.__inverse_square_decimeters = None
        
        self.__inverse_square_centimeters = None
        
        self.__inverse_square_millimeters = None
        
        self.__inverse_square_micrometers = None
        
        self.__inverse_square_miles = None
        
        self.__inverse_square_yards = None
        
        self.__inverse_square_feet = None
        
        self.__inverse_us_survey_square_feet = None
        
        self.__inverse_square_inches = None
        

    def __convert_from_base(self, from_unit: ReciprocalAreaUnits) -> float:
        value = self.__value
        
        if from_unit == ReciprocalAreaUnits.InverseSquareMeter:
            return (value)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareKilometer:
            return (value * 1e6)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareDecimeter:
            return (value * 1e-2)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareCentimeter:
            return (value * 1e-4)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareMillimeter:
            return (value * 1e-6)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareMicrometer:
            return (value * 1e-12)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareMile:
            return (value * 2.59e6)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareYard:
            return (value * 0.836127)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareFoot:
            return (value * 0.092903)
        
        if from_unit == ReciprocalAreaUnits.InverseUsSurveySquareFoot:
            return (value * 0.09290341161)
        
        if from_unit == ReciprocalAreaUnits.InverseSquareInch:
            return (value * 0.00064516)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ReciprocalAreaUnits) -> float:
        
        if to_unit == ReciprocalAreaUnits.InverseSquareMeter:
            return (value)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareKilometer:
            return (value / 1e6)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareDecimeter:
            return (value / 1e-2)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareCentimeter:
            return (value / 1e-4)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareMillimeter:
            return (value / 1e-6)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareMicrometer:
            return (value / 1e-12)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareMile:
            return (value / 2.59e6)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareYard:
            return (value / 0.836127)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareFoot:
            return (value / 0.092903)
        
        if to_unit == ReciprocalAreaUnits.InverseUsSurveySquareFoot:
            return (value / 0.09290341161)
        
        if to_unit == ReciprocalAreaUnits.InverseSquareInch:
            return (value / 0.00064516)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_inverse_square_meters(inverse_square_meters: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_meters.

        

        :param meters: The ReciprocalArea value in inverse_square_meters.
        :type inverse_square_meters: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_meters, ReciprocalAreaUnits.InverseSquareMeter)

    
    @staticmethod
    def from_inverse_square_kilometers(inverse_square_kilometers: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_kilometers.

        

        :param meters: The ReciprocalArea value in inverse_square_kilometers.
        :type inverse_square_kilometers: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_kilometers, ReciprocalAreaUnits.InverseSquareKilometer)

    
    @staticmethod
    def from_inverse_square_decimeters(inverse_square_decimeters: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_decimeters.

        

        :param meters: The ReciprocalArea value in inverse_square_decimeters.
        :type inverse_square_decimeters: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_decimeters, ReciprocalAreaUnits.InverseSquareDecimeter)

    
    @staticmethod
    def from_inverse_square_centimeters(inverse_square_centimeters: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_centimeters.

        

        :param meters: The ReciprocalArea value in inverse_square_centimeters.
        :type inverse_square_centimeters: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_centimeters, ReciprocalAreaUnits.InverseSquareCentimeter)

    
    @staticmethod
    def from_inverse_square_millimeters(inverse_square_millimeters: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_millimeters.

        

        :param meters: The ReciprocalArea value in inverse_square_millimeters.
        :type inverse_square_millimeters: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_millimeters, ReciprocalAreaUnits.InverseSquareMillimeter)

    
    @staticmethod
    def from_inverse_square_micrometers(inverse_square_micrometers: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_micrometers.

        

        :param meters: The ReciprocalArea value in inverse_square_micrometers.
        :type inverse_square_micrometers: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_micrometers, ReciprocalAreaUnits.InverseSquareMicrometer)

    
    @staticmethod
    def from_inverse_square_miles(inverse_square_miles: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_miles.

        

        :param meters: The ReciprocalArea value in inverse_square_miles.
        :type inverse_square_miles: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_miles, ReciprocalAreaUnits.InverseSquareMile)

    
    @staticmethod
    def from_inverse_square_yards(inverse_square_yards: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_yards.

        

        :param meters: The ReciprocalArea value in inverse_square_yards.
        :type inverse_square_yards: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_yards, ReciprocalAreaUnits.InverseSquareYard)

    
    @staticmethod
    def from_inverse_square_feet(inverse_square_feet: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_feet.

        

        :param meters: The ReciprocalArea value in inverse_square_feet.
        :type inverse_square_feet: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_feet, ReciprocalAreaUnits.InverseSquareFoot)

    
    @staticmethod
    def from_inverse_us_survey_square_feet(inverse_us_survey_square_feet: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_us_survey_square_feet.

        

        :param meters: The ReciprocalArea value in inverse_us_survey_square_feet.
        :type inverse_us_survey_square_feet: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_us_survey_square_feet, ReciprocalAreaUnits.InverseUsSurveySquareFoot)

    
    @staticmethod
    def from_inverse_square_inches(inverse_square_inches: float):
        """
        Create a new instance of ReciprocalArea from a value in inverse_square_inches.

        

        :param meters: The ReciprocalArea value in inverse_square_inches.
        :type inverse_square_inches: float
        :return: A new instance of ReciprocalArea.
        :rtype: ReciprocalArea
        """
        return ReciprocalArea(inverse_square_inches, ReciprocalAreaUnits.InverseSquareInch)

    
    @property
    def inverse_square_meters(self) -> float:
        """
        
        """
        if self.__inverse_square_meters != None:
            return self.__inverse_square_meters
        self.__inverse_square_meters = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareMeter)
        return self.__inverse_square_meters

    
    @property
    def inverse_square_kilometers(self) -> float:
        """
        
        """
        if self.__inverse_square_kilometers != None:
            return self.__inverse_square_kilometers
        self.__inverse_square_kilometers = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareKilometer)
        return self.__inverse_square_kilometers

    
    @property
    def inverse_square_decimeters(self) -> float:
        """
        
        """
        if self.__inverse_square_decimeters != None:
            return self.__inverse_square_decimeters
        self.__inverse_square_decimeters = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareDecimeter)
        return self.__inverse_square_decimeters

    
    @property
    def inverse_square_centimeters(self) -> float:
        """
        
        """
        if self.__inverse_square_centimeters != None:
            return self.__inverse_square_centimeters
        self.__inverse_square_centimeters = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareCentimeter)
        return self.__inverse_square_centimeters

    
    @property
    def inverse_square_millimeters(self) -> float:
        """
        
        """
        if self.__inverse_square_millimeters != None:
            return self.__inverse_square_millimeters
        self.__inverse_square_millimeters = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareMillimeter)
        return self.__inverse_square_millimeters

    
    @property
    def inverse_square_micrometers(self) -> float:
        """
        
        """
        if self.__inverse_square_micrometers != None:
            return self.__inverse_square_micrometers
        self.__inverse_square_micrometers = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareMicrometer)
        return self.__inverse_square_micrometers

    
    @property
    def inverse_square_miles(self) -> float:
        """
        
        """
        if self.__inverse_square_miles != None:
            return self.__inverse_square_miles
        self.__inverse_square_miles = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareMile)
        return self.__inverse_square_miles

    
    @property
    def inverse_square_yards(self) -> float:
        """
        
        """
        if self.__inverse_square_yards != None:
            return self.__inverse_square_yards
        self.__inverse_square_yards = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareYard)
        return self.__inverse_square_yards

    
    @property
    def inverse_square_feet(self) -> float:
        """
        
        """
        if self.__inverse_square_feet != None:
            return self.__inverse_square_feet
        self.__inverse_square_feet = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareFoot)
        return self.__inverse_square_feet

    
    @property
    def inverse_us_survey_square_feet(self) -> float:
        """
        
        """
        if self.__inverse_us_survey_square_feet != None:
            return self.__inverse_us_survey_square_feet
        self.__inverse_us_survey_square_feet = self.__convert_from_base(ReciprocalAreaUnits.InverseUsSurveySquareFoot)
        return self.__inverse_us_survey_square_feet

    
    @property
    def inverse_square_inches(self) -> float:
        """
        
        """
        if self.__inverse_square_inches != None:
            return self.__inverse_square_inches
        self.__inverse_square_inches = self.__convert_from_base(ReciprocalAreaUnits.InverseSquareInch)
        return self.__inverse_square_inches

    
    def to_string(self, unit: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter) -> string:
        """
        Format the ReciprocalArea to string.
        Note! the default format for ReciprocalArea is InverseSquareMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ReciprocalAreaUnits.InverseSquareMeter:
            return f"""{self.inverse_square_meters} m⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareKilometer:
            return f"""{self.inverse_square_kilometers} km⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareDecimeter:
            return f"""{self.inverse_square_decimeters} dm⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareCentimeter:
            return f"""{self.inverse_square_centimeters} cm⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareMillimeter:
            return f"""{self.inverse_square_millimeters} mm⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareMicrometer:
            return f"""{self.inverse_square_micrometers} µm⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareMile:
            return f"""{self.inverse_square_miles} mi⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareYard:
            return f"""{self.inverse_square_yards} yd⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseSquareFoot:
            return f"""{self.inverse_square_feet} ft⁻²"""
        
        if unit == ReciprocalAreaUnits.InverseUsSurveySquareFoot:
            return f"""{self.inverse_us_survey_square_feet} ft⁻² (US)"""
        
        if unit == ReciprocalAreaUnits.InverseSquareInch:
            return f"""{self.inverse_square_inches} in⁻²"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter) -> string:
        """
        Get ReciprocalArea unit abbreviation.
        Note! the default abbreviation for ReciprocalArea is InverseSquareMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareMeter:
            return """m⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareKilometer:
            return """km⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareDecimeter:
            return """dm⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareCentimeter:
            return """cm⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareMillimeter:
            return """mm⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareMicrometer:
            return """µm⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareMile:
            return """mi⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareYard:
            return """yd⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareFoot:
            return """ft⁻²"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseUsSurveySquareFoot:
            return """ft⁻² (US)"""
        
        if unit_abbreviation == ReciprocalAreaUnits.InverseSquareInch:
            return """in⁻²"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for +: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return ReciprocalArea(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for *: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return ReciprocalArea(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for -: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return ReciprocalArea(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for /: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return ReciprocalArea(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for %: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return ReciprocalArea(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for **: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return ReciprocalArea(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for ==: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for <: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for >: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for <=: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ReciprocalArea):
            raise TypeError("unsupported operand type(s) for >=: 'ReciprocalArea' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class JerkUnits(Enum):
        """
            JerkUnits enumeration
        """
        
        MeterPerSecondCubed = 'meter_per_second_cubed'
        """
            
        """
        
        InchPerSecondCubed = 'inch_per_second_cubed'
        """
            
        """
        
        FootPerSecondCubed = 'foot_per_second_cubed'
        """
            
        """
        
        StandardGravitiesPerSecond = 'standard_gravities_per_second'
        """
            
        """
        
        NanometerPerSecondCubed = 'nanometer_per_second_cubed'
        """
            
        """
        
        MicrometerPerSecondCubed = 'micrometer_per_second_cubed'
        """
            
        """
        
        MillimeterPerSecondCubed = 'millimeter_per_second_cubed'
        """
            
        """
        
        CentimeterPerSecondCubed = 'centimeter_per_second_cubed'
        """
            
        """
        
        DecimeterPerSecondCubed = 'decimeter_per_second_cubed'
        """
            
        """
        
        KilometerPerSecondCubed = 'kilometer_per_second_cubed'
        """
            
        """
        
        MillistandardGravitiesPerSecond = 'millistandard_gravities_per_second'
        """
            
        """
        

class Jerk:
    """
    None

    Args:
        value (float): The value.
        from_unit (JerkUnits): The Jerk unit to create from, The default unit is MeterPerSecondCubed
    """
    def __init__(self, value: float, from_unit: JerkUnits = JerkUnits.MeterPerSecondCubed):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__meters_per_second_cubed = None
        
        self.__inches_per_second_cubed = None
        
        self.__feet_per_second_cubed = None
        
        self.__standard_gravities_per_second = None
        
        self.__nanometers_per_second_cubed = None
        
        self.__micrometers_per_second_cubed = None
        
        self.__millimeters_per_second_cubed = None
        
        self.__centimeters_per_second_cubed = None
        
        self.__decimeters_per_second_cubed = None
        
        self.__kilometers_per_second_cubed = None
        
        self.__millistandard_gravities_per_second = None
        

    def __convert_from_base(self, from_unit: JerkUnits) -> float:
        value = self.__value
        
        if from_unit == JerkUnits.MeterPerSecondCubed:
            return (value)
        
        if from_unit == JerkUnits.InchPerSecondCubed:
            return (value / 0.0254)
        
        if from_unit == JerkUnits.FootPerSecondCubed:
            return (value / 0.304800)
        
        if from_unit == JerkUnits.StandardGravitiesPerSecond:
            return (value / 9.80665)
        
        if from_unit == JerkUnits.NanometerPerSecondCubed:
            return ((value) / 1e-09)
        
        if from_unit == JerkUnits.MicrometerPerSecondCubed:
            return ((value) / 1e-06)
        
        if from_unit == JerkUnits.MillimeterPerSecondCubed:
            return ((value) / 0.001)
        
        if from_unit == JerkUnits.CentimeterPerSecondCubed:
            return ((value) / 0.01)
        
        if from_unit == JerkUnits.DecimeterPerSecondCubed:
            return ((value) / 0.1)
        
        if from_unit == JerkUnits.KilometerPerSecondCubed:
            return ((value) / 1000.0)
        
        if from_unit == JerkUnits.MillistandardGravitiesPerSecond:
            return ((value / 9.80665) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: JerkUnits) -> float:
        
        if to_unit == JerkUnits.MeterPerSecondCubed:
            return (value)
        
        if to_unit == JerkUnits.InchPerSecondCubed:
            return (value * 0.0254)
        
        if to_unit == JerkUnits.FootPerSecondCubed:
            return (value * 0.304800)
        
        if to_unit == JerkUnits.StandardGravitiesPerSecond:
            return (value * 9.80665)
        
        if to_unit == JerkUnits.NanometerPerSecondCubed:
            return ((value) * 1e-09)
        
        if to_unit == JerkUnits.MicrometerPerSecondCubed:
            return ((value) * 1e-06)
        
        if to_unit == JerkUnits.MillimeterPerSecondCubed:
            return ((value) * 0.001)
        
        if to_unit == JerkUnits.CentimeterPerSecondCubed:
            return ((value) * 0.01)
        
        if to_unit == JerkUnits.DecimeterPerSecondCubed:
            return ((value) * 0.1)
        
        if to_unit == JerkUnits.KilometerPerSecondCubed:
            return ((value) * 1000.0)
        
        if to_unit == JerkUnits.MillistandardGravitiesPerSecond:
            return ((value * 9.80665) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_meters_per_second_cubed(meters_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in meters_per_second_cubed.

        

        :param meters: The Jerk value in meters_per_second_cubed.
        :type meters_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(meters_per_second_cubed, JerkUnits.MeterPerSecondCubed)

    
    @staticmethod
    def from_inches_per_second_cubed(inches_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in inches_per_second_cubed.

        

        :param meters: The Jerk value in inches_per_second_cubed.
        :type inches_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(inches_per_second_cubed, JerkUnits.InchPerSecondCubed)

    
    @staticmethod
    def from_feet_per_second_cubed(feet_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in feet_per_second_cubed.

        

        :param meters: The Jerk value in feet_per_second_cubed.
        :type feet_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(feet_per_second_cubed, JerkUnits.FootPerSecondCubed)

    
    @staticmethod
    def from_standard_gravities_per_second(standard_gravities_per_second: float):
        """
        Create a new instance of Jerk from a value in standard_gravities_per_second.

        

        :param meters: The Jerk value in standard_gravities_per_second.
        :type standard_gravities_per_second: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(standard_gravities_per_second, JerkUnits.StandardGravitiesPerSecond)

    
    @staticmethod
    def from_nanometers_per_second_cubed(nanometers_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in nanometers_per_second_cubed.

        

        :param meters: The Jerk value in nanometers_per_second_cubed.
        :type nanometers_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(nanometers_per_second_cubed, JerkUnits.NanometerPerSecondCubed)

    
    @staticmethod
    def from_micrometers_per_second_cubed(micrometers_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in micrometers_per_second_cubed.

        

        :param meters: The Jerk value in micrometers_per_second_cubed.
        :type micrometers_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(micrometers_per_second_cubed, JerkUnits.MicrometerPerSecondCubed)

    
    @staticmethod
    def from_millimeters_per_second_cubed(millimeters_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in millimeters_per_second_cubed.

        

        :param meters: The Jerk value in millimeters_per_second_cubed.
        :type millimeters_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(millimeters_per_second_cubed, JerkUnits.MillimeterPerSecondCubed)

    
    @staticmethod
    def from_centimeters_per_second_cubed(centimeters_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in centimeters_per_second_cubed.

        

        :param meters: The Jerk value in centimeters_per_second_cubed.
        :type centimeters_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(centimeters_per_second_cubed, JerkUnits.CentimeterPerSecondCubed)

    
    @staticmethod
    def from_decimeters_per_second_cubed(decimeters_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in decimeters_per_second_cubed.

        

        :param meters: The Jerk value in decimeters_per_second_cubed.
        :type decimeters_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(decimeters_per_second_cubed, JerkUnits.DecimeterPerSecondCubed)

    
    @staticmethod
    def from_kilometers_per_second_cubed(kilometers_per_second_cubed: float):
        """
        Create a new instance of Jerk from a value in kilometers_per_second_cubed.

        

        :param meters: The Jerk value in kilometers_per_second_cubed.
        :type kilometers_per_second_cubed: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(kilometers_per_second_cubed, JerkUnits.KilometerPerSecondCubed)

    
    @staticmethod
    def from_millistandard_gravities_per_second(millistandard_gravities_per_second: float):
        """
        Create a new instance of Jerk from a value in millistandard_gravities_per_second.

        

        :param meters: The Jerk value in millistandard_gravities_per_second.
        :type millistandard_gravities_per_second: float
        :return: A new instance of Jerk.
        :rtype: Jerk
        """
        return Jerk(millistandard_gravities_per_second, JerkUnits.MillistandardGravitiesPerSecond)

    
    @property
    def meters_per_second_cubed(self) -> float:
        """
        
        """
        if self.__meters_per_second_cubed != None:
            return self.__meters_per_second_cubed
        self.__meters_per_second_cubed = self.__convert_from_base(JerkUnits.MeterPerSecondCubed)
        return self.__meters_per_second_cubed

    
    @property
    def inches_per_second_cubed(self) -> float:
        """
        
        """
        if self.__inches_per_second_cubed != None:
            return self.__inches_per_second_cubed
        self.__inches_per_second_cubed = self.__convert_from_base(JerkUnits.InchPerSecondCubed)
        return self.__inches_per_second_cubed

    
    @property
    def feet_per_second_cubed(self) -> float:
        """
        
        """
        if self.__feet_per_second_cubed != None:
            return self.__feet_per_second_cubed
        self.__feet_per_second_cubed = self.__convert_from_base(JerkUnits.FootPerSecondCubed)
        return self.__feet_per_second_cubed

    
    @property
    def standard_gravities_per_second(self) -> float:
        """
        
        """
        if self.__standard_gravities_per_second != None:
            return self.__standard_gravities_per_second
        self.__standard_gravities_per_second = self.__convert_from_base(JerkUnits.StandardGravitiesPerSecond)
        return self.__standard_gravities_per_second

    
    @property
    def nanometers_per_second_cubed(self) -> float:
        """
        
        """
        if self.__nanometers_per_second_cubed != None:
            return self.__nanometers_per_second_cubed
        self.__nanometers_per_second_cubed = self.__convert_from_base(JerkUnits.NanometerPerSecondCubed)
        return self.__nanometers_per_second_cubed

    
    @property
    def micrometers_per_second_cubed(self) -> float:
        """
        
        """
        if self.__micrometers_per_second_cubed != None:
            return self.__micrometers_per_second_cubed
        self.__micrometers_per_second_cubed = self.__convert_from_base(JerkUnits.MicrometerPerSecondCubed)
        return self.__micrometers_per_second_cubed

    
    @property
    def millimeters_per_second_cubed(self) -> float:
        """
        
        """
        if self.__millimeters_per_second_cubed != None:
            return self.__millimeters_per_second_cubed
        self.__millimeters_per_second_cubed = self.__convert_from_base(JerkUnits.MillimeterPerSecondCubed)
        return self.__millimeters_per_second_cubed

    
    @property
    def centimeters_per_second_cubed(self) -> float:
        """
        
        """
        if self.__centimeters_per_second_cubed != None:
            return self.__centimeters_per_second_cubed
        self.__centimeters_per_second_cubed = self.__convert_from_base(JerkUnits.CentimeterPerSecondCubed)
        return self.__centimeters_per_second_cubed

    
    @property
    def decimeters_per_second_cubed(self) -> float:
        """
        
        """
        if self.__decimeters_per_second_cubed != None:
            return self.__decimeters_per_second_cubed
        self.__decimeters_per_second_cubed = self.__convert_from_base(JerkUnits.DecimeterPerSecondCubed)
        return self.__decimeters_per_second_cubed

    
    @property
    def kilometers_per_second_cubed(self) -> float:
        """
        
        """
        if self.__kilometers_per_second_cubed != None:
            return self.__kilometers_per_second_cubed
        self.__kilometers_per_second_cubed = self.__convert_from_base(JerkUnits.KilometerPerSecondCubed)
        return self.__kilometers_per_second_cubed

    
    @property
    def millistandard_gravities_per_second(self) -> float:
        """
        
        """
        if self.__millistandard_gravities_per_second != None:
            return self.__millistandard_gravities_per_second
        self.__millistandard_gravities_per_second = self.__convert_from_base(JerkUnits.MillistandardGravitiesPerSecond)
        return self.__millistandard_gravities_per_second

    
    def to_string(self, unit: JerkUnits = JerkUnits.MeterPerSecondCubed) -> string:
        """
        Format the Jerk to string.
        Note! the default format for Jerk is MeterPerSecondCubed.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == JerkUnits.MeterPerSecondCubed:
            return f"""{self.meters_per_second_cubed} m/s³"""
        
        if unit == JerkUnits.InchPerSecondCubed:
            return f"""{self.inches_per_second_cubed} in/s³"""
        
        if unit == JerkUnits.FootPerSecondCubed:
            return f"""{self.feet_per_second_cubed} ft/s³"""
        
        if unit == JerkUnits.StandardGravitiesPerSecond:
            return f"""{self.standard_gravities_per_second} g/s"""
        
        if unit == JerkUnits.NanometerPerSecondCubed:
            return f"""{self.nanometers_per_second_cubed} """
        
        if unit == JerkUnits.MicrometerPerSecondCubed:
            return f"""{self.micrometers_per_second_cubed} """
        
        if unit == JerkUnits.MillimeterPerSecondCubed:
            return f"""{self.millimeters_per_second_cubed} """
        
        if unit == JerkUnits.CentimeterPerSecondCubed:
            return f"""{self.centimeters_per_second_cubed} """
        
        if unit == JerkUnits.DecimeterPerSecondCubed:
            return f"""{self.decimeters_per_second_cubed} """
        
        if unit == JerkUnits.KilometerPerSecondCubed:
            return f"""{self.kilometers_per_second_cubed} """
        
        if unit == JerkUnits.MillistandardGravitiesPerSecond:
            return f"""{self.millistandard_gravities_per_second} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: JerkUnits = JerkUnits.MeterPerSecondCubed) -> string:
        """
        Get Jerk unit abbreviation.
        Note! the default abbreviation for Jerk is MeterPerSecondCubed.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == JerkUnits.MeterPerSecondCubed:
            return """m/s³"""
        
        if unit_abbreviation == JerkUnits.InchPerSecondCubed:
            return """in/s³"""
        
        if unit_abbreviation == JerkUnits.FootPerSecondCubed:
            return """ft/s³"""
        
        if unit_abbreviation == JerkUnits.StandardGravitiesPerSecond:
            return """g/s"""
        
        if unit_abbreviation == JerkUnits.NanometerPerSecondCubed:
            return """"""
        
        if unit_abbreviation == JerkUnits.MicrometerPerSecondCubed:
            return """"""
        
        if unit_abbreviation == JerkUnits.MillimeterPerSecondCubed:
            return """"""
        
        if unit_abbreviation == JerkUnits.CentimeterPerSecondCubed:
            return """"""
        
        if unit_abbreviation == JerkUnits.DecimeterPerSecondCubed:
            return """"""
        
        if unit_abbreviation == JerkUnits.KilometerPerSecondCubed:
            return """"""
        
        if unit_abbreviation == JerkUnits.MillistandardGravitiesPerSecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for +: 'Jerk' and '{}'".format(type(other).__name__))
        return Jerk(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for *: 'Jerk' and '{}'".format(type(other).__name__))
        return Jerk(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for -: 'Jerk' and '{}'".format(type(other).__name__))
        return Jerk(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for /: 'Jerk' and '{}'".format(type(other).__name__))
        return Jerk(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for %: 'Jerk' and '{}'".format(type(other).__name__))
        return Jerk(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for **: 'Jerk' and '{}'".format(type(other).__name__))
        return Jerk(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for ==: 'Jerk' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for <: 'Jerk' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for >: 'Jerk' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for <=: 'Jerk' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Jerk):
            raise TypeError("unsupported operand type(s) for >=: 'Jerk' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class EntropyUnits(Enum):
        """
            EntropyUnits enumeration
        """
        
        JoulePerKelvin = 'joule_per_kelvin'
        """
            
        """
        
        CaloriePerKelvin = 'calorie_per_kelvin'
        """
            
        """
        
        JoulePerDegreeCelsius = 'joule_per_degree_celsius'
        """
            
        """
        
        KilojoulePerKelvin = 'kilojoule_per_kelvin'
        """
            
        """
        
        MegajoulePerKelvin = 'megajoule_per_kelvin'
        """
            
        """
        
        KilocaloriePerKelvin = 'kilocalorie_per_kelvin'
        """
            
        """
        
        KilojoulePerDegreeCelsius = 'kilojoule_per_degree_celsius'
        """
            
        """
        

class Entropy:
    """
    Entropy is an important concept in the branch of science known as thermodynamics. The idea of "irreversibility" is central to the understanding of entropy.  It is often said that entropy is an expression of the disorder, or randomness of a system, or of our lack of information about it. Entropy is an extensive property. It has the dimension of energy divided by temperature, which has a unit of joules per kelvin (J/K) in the International System of Units

    Args:
        value (float): The value.
        from_unit (EntropyUnits): The Entropy unit to create from, The default unit is JoulePerKelvin
    """
    def __init__(self, value: float, from_unit: EntropyUnits = EntropyUnits.JoulePerKelvin):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__joules_per_kelvin = None
        
        self.__calories_per_kelvin = None
        
        self.__joules_per_degree_celsius = None
        
        self.__kilojoules_per_kelvin = None
        
        self.__megajoules_per_kelvin = None
        
        self.__kilocalories_per_kelvin = None
        
        self.__kilojoules_per_degree_celsius = None
        

    def __convert_from_base(self, from_unit: EntropyUnits) -> float:
        value = self.__value
        
        if from_unit == EntropyUnits.JoulePerKelvin:
            return (value)
        
        if from_unit == EntropyUnits.CaloriePerKelvin:
            return (value / 4.184)
        
        if from_unit == EntropyUnits.JoulePerDegreeCelsius:
            return (value)
        
        if from_unit == EntropyUnits.KilojoulePerKelvin:
            return ((value) / 1000.0)
        
        if from_unit == EntropyUnits.MegajoulePerKelvin:
            return ((value) / 1000000.0)
        
        if from_unit == EntropyUnits.KilocaloriePerKelvin:
            return ((value / 4.184) / 1000.0)
        
        if from_unit == EntropyUnits.KilojoulePerDegreeCelsius:
            return ((value) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: EntropyUnits) -> float:
        
        if to_unit == EntropyUnits.JoulePerKelvin:
            return (value)
        
        if to_unit == EntropyUnits.CaloriePerKelvin:
            return (value * 4.184)
        
        if to_unit == EntropyUnits.JoulePerDegreeCelsius:
            return (value)
        
        if to_unit == EntropyUnits.KilojoulePerKelvin:
            return ((value) * 1000.0)
        
        if to_unit == EntropyUnits.MegajoulePerKelvin:
            return ((value) * 1000000.0)
        
        if to_unit == EntropyUnits.KilocaloriePerKelvin:
            return ((value * 4.184) * 1000.0)
        
        if to_unit == EntropyUnits.KilojoulePerDegreeCelsius:
            return ((value) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_joules_per_kelvin(joules_per_kelvin: float):
        """
        Create a new instance of Entropy from a value in joules_per_kelvin.

        

        :param meters: The Entropy value in joules_per_kelvin.
        :type joules_per_kelvin: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(joules_per_kelvin, EntropyUnits.JoulePerKelvin)

    
    @staticmethod
    def from_calories_per_kelvin(calories_per_kelvin: float):
        """
        Create a new instance of Entropy from a value in calories_per_kelvin.

        

        :param meters: The Entropy value in calories_per_kelvin.
        :type calories_per_kelvin: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(calories_per_kelvin, EntropyUnits.CaloriePerKelvin)

    
    @staticmethod
    def from_joules_per_degree_celsius(joules_per_degree_celsius: float):
        """
        Create a new instance of Entropy from a value in joules_per_degree_celsius.

        

        :param meters: The Entropy value in joules_per_degree_celsius.
        :type joules_per_degree_celsius: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(joules_per_degree_celsius, EntropyUnits.JoulePerDegreeCelsius)

    
    @staticmethod
    def from_kilojoules_per_kelvin(kilojoules_per_kelvin: float):
        """
        Create a new instance of Entropy from a value in kilojoules_per_kelvin.

        

        :param meters: The Entropy value in kilojoules_per_kelvin.
        :type kilojoules_per_kelvin: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(kilojoules_per_kelvin, EntropyUnits.KilojoulePerKelvin)

    
    @staticmethod
    def from_megajoules_per_kelvin(megajoules_per_kelvin: float):
        """
        Create a new instance of Entropy from a value in megajoules_per_kelvin.

        

        :param meters: The Entropy value in megajoules_per_kelvin.
        :type megajoules_per_kelvin: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(megajoules_per_kelvin, EntropyUnits.MegajoulePerKelvin)

    
    @staticmethod
    def from_kilocalories_per_kelvin(kilocalories_per_kelvin: float):
        """
        Create a new instance of Entropy from a value in kilocalories_per_kelvin.

        

        :param meters: The Entropy value in kilocalories_per_kelvin.
        :type kilocalories_per_kelvin: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(kilocalories_per_kelvin, EntropyUnits.KilocaloriePerKelvin)

    
    @staticmethod
    def from_kilojoules_per_degree_celsius(kilojoules_per_degree_celsius: float):
        """
        Create a new instance of Entropy from a value in kilojoules_per_degree_celsius.

        

        :param meters: The Entropy value in kilojoules_per_degree_celsius.
        :type kilojoules_per_degree_celsius: float
        :return: A new instance of Entropy.
        :rtype: Entropy
        """
        return Entropy(kilojoules_per_degree_celsius, EntropyUnits.KilojoulePerDegreeCelsius)

    
    @property
    def joules_per_kelvin(self) -> float:
        """
        
        """
        if self.__joules_per_kelvin != None:
            return self.__joules_per_kelvin
        self.__joules_per_kelvin = self.__convert_from_base(EntropyUnits.JoulePerKelvin)
        return self.__joules_per_kelvin

    
    @property
    def calories_per_kelvin(self) -> float:
        """
        
        """
        if self.__calories_per_kelvin != None:
            return self.__calories_per_kelvin
        self.__calories_per_kelvin = self.__convert_from_base(EntropyUnits.CaloriePerKelvin)
        return self.__calories_per_kelvin

    
    @property
    def joules_per_degree_celsius(self) -> float:
        """
        
        """
        if self.__joules_per_degree_celsius != None:
            return self.__joules_per_degree_celsius
        self.__joules_per_degree_celsius = self.__convert_from_base(EntropyUnits.JoulePerDegreeCelsius)
        return self.__joules_per_degree_celsius

    
    @property
    def kilojoules_per_kelvin(self) -> float:
        """
        
        """
        if self.__kilojoules_per_kelvin != None:
            return self.__kilojoules_per_kelvin
        self.__kilojoules_per_kelvin = self.__convert_from_base(EntropyUnits.KilojoulePerKelvin)
        return self.__kilojoules_per_kelvin

    
    @property
    def megajoules_per_kelvin(self) -> float:
        """
        
        """
        if self.__megajoules_per_kelvin != None:
            return self.__megajoules_per_kelvin
        self.__megajoules_per_kelvin = self.__convert_from_base(EntropyUnits.MegajoulePerKelvin)
        return self.__megajoules_per_kelvin

    
    @property
    def kilocalories_per_kelvin(self) -> float:
        """
        
        """
        if self.__kilocalories_per_kelvin != None:
            return self.__kilocalories_per_kelvin
        self.__kilocalories_per_kelvin = self.__convert_from_base(EntropyUnits.KilocaloriePerKelvin)
        return self.__kilocalories_per_kelvin

    
    @property
    def kilojoules_per_degree_celsius(self) -> float:
        """
        
        """
        if self.__kilojoules_per_degree_celsius != None:
            return self.__kilojoules_per_degree_celsius
        self.__kilojoules_per_degree_celsius = self.__convert_from_base(EntropyUnits.KilojoulePerDegreeCelsius)
        return self.__kilojoules_per_degree_celsius

    
    def to_string(self, unit: EntropyUnits = EntropyUnits.JoulePerKelvin) -> string:
        """
        Format the Entropy to string.
        Note! the default format for Entropy is JoulePerKelvin.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == EntropyUnits.JoulePerKelvin:
            return f"""{self.joules_per_kelvin} J/K"""
        
        if unit == EntropyUnits.CaloriePerKelvin:
            return f"""{self.calories_per_kelvin} cal/K"""
        
        if unit == EntropyUnits.JoulePerDegreeCelsius:
            return f"""{self.joules_per_degree_celsius} J/C"""
        
        if unit == EntropyUnits.KilojoulePerKelvin:
            return f"""{self.kilojoules_per_kelvin} """
        
        if unit == EntropyUnits.MegajoulePerKelvin:
            return f"""{self.megajoules_per_kelvin} """
        
        if unit == EntropyUnits.KilocaloriePerKelvin:
            return f"""{self.kilocalories_per_kelvin} """
        
        if unit == EntropyUnits.KilojoulePerDegreeCelsius:
            return f"""{self.kilojoules_per_degree_celsius} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: EntropyUnits = EntropyUnits.JoulePerKelvin) -> string:
        """
        Get Entropy unit abbreviation.
        Note! the default abbreviation for Entropy is JoulePerKelvin.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == EntropyUnits.JoulePerKelvin:
            return """J/K"""
        
        if unit_abbreviation == EntropyUnits.CaloriePerKelvin:
            return """cal/K"""
        
        if unit_abbreviation == EntropyUnits.JoulePerDegreeCelsius:
            return """J/C"""
        
        if unit_abbreviation == EntropyUnits.KilojoulePerKelvin:
            return """"""
        
        if unit_abbreviation == EntropyUnits.MegajoulePerKelvin:
            return """"""
        
        if unit_abbreviation == EntropyUnits.KilocaloriePerKelvin:
            return """"""
        
        if unit_abbreviation == EntropyUnits.KilojoulePerDegreeCelsius:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for +: 'Entropy' and '{}'".format(type(other).__name__))
        return Entropy(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for *: 'Entropy' and '{}'".format(type(other).__name__))
        return Entropy(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for -: 'Entropy' and '{}'".format(type(other).__name__))
        return Entropy(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for /: 'Entropy' and '{}'".format(type(other).__name__))
        return Entropy(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for %: 'Entropy' and '{}'".format(type(other).__name__))
        return Entropy(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for **: 'Entropy' and '{}'".format(type(other).__name__))
        return Entropy(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for ==: 'Entropy' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for <: 'Entropy' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for >: 'Entropy' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for <=: 'Entropy' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Entropy):
            raise TypeError("unsupported operand type(s) for >=: 'Entropy' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class PowerRatioUnits(Enum):
        """
            PowerRatioUnits enumeration
        """
        
        DecibelWatt = 'decibel_watt'
        """
            
        """
        
        DecibelMilliwatt = 'decibel_milliwatt'
        """
            
        """
        

class PowerRatio:
    """
    The strength of a signal expressed in decibels (dB) relative to one watt.

    Args:
        value (float): The value.
        from_unit (PowerRatioUnits): The PowerRatio unit to create from, The default unit is DecibelWatt
    """
    def __init__(self, value: float, from_unit: PowerRatioUnits = PowerRatioUnits.DecibelWatt):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__decibel_watts = None
        
        self.__decibel_milliwatts = None
        

    def __convert_from_base(self, from_unit: PowerRatioUnits) -> float:
        value = self.__value
        
        if from_unit == PowerRatioUnits.DecibelWatt:
            return (value)
        
        if from_unit == PowerRatioUnits.DecibelMilliwatt:
            return (value + 30)
        
        return None


    def __convert_to_base(self, value: float, to_unit: PowerRatioUnits) -> float:
        
        if to_unit == PowerRatioUnits.DecibelWatt:
            return (value)
        
        if to_unit == PowerRatioUnits.DecibelMilliwatt:
            return (value - 30)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_decibel_watts(decibel_watts: float):
        """
        Create a new instance of PowerRatio from a value in decibel_watts.

        

        :param meters: The PowerRatio value in decibel_watts.
        :type decibel_watts: float
        :return: A new instance of PowerRatio.
        :rtype: PowerRatio
        """
        return PowerRatio(decibel_watts, PowerRatioUnits.DecibelWatt)

    
    @staticmethod
    def from_decibel_milliwatts(decibel_milliwatts: float):
        """
        Create a new instance of PowerRatio from a value in decibel_milliwatts.

        

        :param meters: The PowerRatio value in decibel_milliwatts.
        :type decibel_milliwatts: float
        :return: A new instance of PowerRatio.
        :rtype: PowerRatio
        """
        return PowerRatio(decibel_milliwatts, PowerRatioUnits.DecibelMilliwatt)

    
    @property
    def decibel_watts(self) -> float:
        """
        
        """
        if self.__decibel_watts != None:
            return self.__decibel_watts
        self.__decibel_watts = self.__convert_from_base(PowerRatioUnits.DecibelWatt)
        return self.__decibel_watts

    
    @property
    def decibel_milliwatts(self) -> float:
        """
        
        """
        if self.__decibel_milliwatts != None:
            return self.__decibel_milliwatts
        self.__decibel_milliwatts = self.__convert_from_base(PowerRatioUnits.DecibelMilliwatt)
        return self.__decibel_milliwatts

    
    def to_string(self, unit: PowerRatioUnits = PowerRatioUnits.DecibelWatt) -> string:
        """
        Format the PowerRatio to string.
        Note! the default format for PowerRatio is DecibelWatt.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == PowerRatioUnits.DecibelWatt:
            return f"""{self.decibel_watts} dBW"""
        
        if unit == PowerRatioUnits.DecibelMilliwatt:
            return f"""{self.decibel_milliwatts} dBmW"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: PowerRatioUnits = PowerRatioUnits.DecibelWatt) -> string:
        """
        Get PowerRatio unit abbreviation.
        Note! the default abbreviation for PowerRatio is DecibelWatt.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == PowerRatioUnits.DecibelWatt:
            return """dBW"""
        
        if unit_abbreviation == PowerRatioUnits.DecibelMilliwatt:
            return """dBmW"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for +: 'PowerRatio' and '{}'".format(type(other).__name__))
        return PowerRatio(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for *: 'PowerRatio' and '{}'".format(type(other).__name__))
        return PowerRatio(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for -: 'PowerRatio' and '{}'".format(type(other).__name__))
        return PowerRatio(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for /: 'PowerRatio' and '{}'".format(type(other).__name__))
        return PowerRatio(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for %: 'PowerRatio' and '{}'".format(type(other).__name__))
        return PowerRatio(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for **: 'PowerRatio' and '{}'".format(type(other).__name__))
        return PowerRatio(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for ==: 'PowerRatio' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for <: 'PowerRatio' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for >: 'PowerRatio' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for <=: 'PowerRatio' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, PowerRatio):
            raise TypeError("unsupported operand type(s) for >=: 'PowerRatio' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value